from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Graphic3d import *
from OCC.Core.gp import *
from OCC.Core.Quantity import *
from OCC.Core.Aspect import *
from OCC.Core.TColStd import *
from OCC.Core.Bnd import *
from OCC.Core.TCollection import *
from OCC.Core.Image import *

Handle_V3d_Light = NewType('Handle_V3d_Light', Handle_Graphic3d_CLight)
V3d_Coordinate = NewType('V3d_Coordinate', Standard_Real)
V3d_Light = NewType('V3d_Light', Graphic3d_CLight)
#the following typedef cannot be wrapped as is
V3d_ListOfLightIterator = NewType('V3d_ListOfLightIterator', Any)
#the following typedef cannot be wrapped as is
V3d_ListOfViewIterator = NewType('V3d_ListOfViewIterator', Any)
V3d_Parameter = NewType('V3d_Parameter', Standard_Real)
V3d_TypeOfLight = NewType('V3d_TypeOfLight', Graphic3d_TypeOfLightSource)
V3d_TypeOfShadingModel = NewType('V3d_TypeOfShadingModel', Graphic3d_TypeOfShadingModel)
V3d_ViewPointer = NewType('V3d_ViewPointer', V3d_View)
V3d_ViewerPointer = NewType('V3d_ViewerPointer', V3d_Viewer)

class V3d_ListOfLight:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class V3d_ListOfView:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class V3d_TypeOfPickCamera(IntEnum):
	V3d_POSITIONCAMERA: int = ...
	V3d_SPACECAMERA: int = ...
	V3d_RADIUSTEXTCAMERA: int = ...
	V3d_ExtRADIUSCAMERA: int = ...
	V3d_IntRADIUSCAMERA: int = ...
	V3d_NOTHINGCAMERA: int = ...
V3d_POSITIONCAMERA = V3d_TypeOfPickCamera.V3d_POSITIONCAMERA
V3d_SPACECAMERA = V3d_TypeOfPickCamera.V3d_SPACECAMERA
V3d_RADIUSTEXTCAMERA = V3d_TypeOfPickCamera.V3d_RADIUSTEXTCAMERA
V3d_ExtRADIUSCAMERA = V3d_TypeOfPickCamera.V3d_ExtRADIUSCAMERA
V3d_IntRADIUSCAMERA = V3d_TypeOfPickCamera.V3d_IntRADIUSCAMERA
V3d_NOTHINGCAMERA = V3d_TypeOfPickCamera.V3d_NOTHINGCAMERA

class V3d_TypeOfVisualization(IntEnum):
	V3d_WIREFRAME: int = ...
	V3d_ZBUFFER: int = ...
V3d_WIREFRAME = V3d_TypeOfVisualization.V3d_WIREFRAME
V3d_ZBUFFER = V3d_TypeOfVisualization.V3d_ZBUFFER

class V3d_TypeOfView(IntEnum):
	V3d_ORTHOGRAPHIC: int = ...
	V3d_PERSPECTIVE: int = ...
V3d_ORTHOGRAPHIC = V3d_TypeOfView.V3d_ORTHOGRAPHIC
V3d_PERSPECTIVE = V3d_TypeOfView.V3d_PERSPECTIVE

class V3d_StereoDumpOptions(IntEnum):
	V3d_SDO_MONO: int = ...
	V3d_SDO_LEFT_EYE: int = ...
	V3d_SDO_RIGHT_EYE: int = ...
	V3d_SDO_BLENDED: int = ...
V3d_SDO_MONO = V3d_StereoDumpOptions.V3d_SDO_MONO
V3d_SDO_LEFT_EYE = V3d_StereoDumpOptions.V3d_SDO_LEFT_EYE
V3d_SDO_RIGHT_EYE = V3d_StereoDumpOptions.V3d_SDO_RIGHT_EYE
V3d_SDO_BLENDED = V3d_StereoDumpOptions.V3d_SDO_BLENDED

class V3d_TypeOfOrientation(IntEnum):
	V3d_Xpos: int = ...
	V3d_Ypos: int = ...
	V3d_Zpos: int = ...
	V3d_Xneg: int = ...
	V3d_Yneg: int = ...
	V3d_Zneg: int = ...
	V3d_XposYpos: int = ...
	V3d_XposZpos: int = ...
	V3d_YposZpos: int = ...
	V3d_XnegYneg: int = ...
	V3d_XnegYpos: int = ...
	V3d_XnegZneg: int = ...
	V3d_XnegZpos: int = ...
	V3d_YnegZneg: int = ...
	V3d_YnegZpos: int = ...
	V3d_XposYneg: int = ...
	V3d_XposZneg: int = ...
	V3d_YposZneg: int = ...
	V3d_XposYposZpos: int = ...
	V3d_XposYnegZpos: int = ...
	V3d_XposYposZneg: int = ...
	V3d_XnegYposZpos: int = ...
	V3d_XposYnegZneg: int = ...
	V3d_XnegYposZneg: int = ...
	V3d_XnegYnegZpos: int = ...
	V3d_XnegYnegZneg: int = ...
	V3d_TypeOfOrientation_Zup_AxoLeft: int = ...
	V3d_TypeOfOrientation_Zup_AxoRight: int = ...
	V3d_TypeOfOrientation_Zup_Front: int = ...
	V3d_TypeOfOrientation_Zup_Back: int = ...
	V3d_TypeOfOrientation_Zup_Top: int = ...
	V3d_TypeOfOrientation_Zup_Bottom: int = ...
	V3d_TypeOfOrientation_Zup_Left: int = ...
	V3d_TypeOfOrientation_Zup_Right: int = ...
	V3d_TypeOfOrientation_Yup_AxoLeft: int = ...
	V3d_TypeOfOrientation_Yup_AxoRight: int = ...
	V3d_TypeOfOrientation_Yup_Front: int = ...
	V3d_TypeOfOrientation_Yup_Back: int = ...
	V3d_TypeOfOrientation_Yup_Top: int = ...
	V3d_TypeOfOrientation_Yup_Bottom: int = ...
	V3d_TypeOfOrientation_Yup_Left: int = ...
	V3d_TypeOfOrientation_Yup_Right: int = ...
V3d_Xpos = V3d_TypeOfOrientation.V3d_Xpos
V3d_Ypos = V3d_TypeOfOrientation.V3d_Ypos
V3d_Zpos = V3d_TypeOfOrientation.V3d_Zpos
V3d_Xneg = V3d_TypeOfOrientation.V3d_Xneg
V3d_Yneg = V3d_TypeOfOrientation.V3d_Yneg
V3d_Zneg = V3d_TypeOfOrientation.V3d_Zneg
V3d_XposYpos = V3d_TypeOfOrientation.V3d_XposYpos
V3d_XposZpos = V3d_TypeOfOrientation.V3d_XposZpos
V3d_YposZpos = V3d_TypeOfOrientation.V3d_YposZpos
V3d_XnegYneg = V3d_TypeOfOrientation.V3d_XnegYneg
V3d_XnegYpos = V3d_TypeOfOrientation.V3d_XnegYpos
V3d_XnegZneg = V3d_TypeOfOrientation.V3d_XnegZneg
V3d_XnegZpos = V3d_TypeOfOrientation.V3d_XnegZpos
V3d_YnegZneg = V3d_TypeOfOrientation.V3d_YnegZneg
V3d_YnegZpos = V3d_TypeOfOrientation.V3d_YnegZpos
V3d_XposYneg = V3d_TypeOfOrientation.V3d_XposYneg
V3d_XposZneg = V3d_TypeOfOrientation.V3d_XposZneg
V3d_YposZneg = V3d_TypeOfOrientation.V3d_YposZneg
V3d_XposYposZpos = V3d_TypeOfOrientation.V3d_XposYposZpos
V3d_XposYnegZpos = V3d_TypeOfOrientation.V3d_XposYnegZpos
V3d_XposYposZneg = V3d_TypeOfOrientation.V3d_XposYposZneg
V3d_XnegYposZpos = V3d_TypeOfOrientation.V3d_XnegYposZpos
V3d_XposYnegZneg = V3d_TypeOfOrientation.V3d_XposYnegZneg
V3d_XnegYposZneg = V3d_TypeOfOrientation.V3d_XnegYposZneg
V3d_XnegYnegZpos = V3d_TypeOfOrientation.V3d_XnegYnegZpos
V3d_XnegYnegZneg = V3d_TypeOfOrientation.V3d_XnegYnegZneg
V3d_TypeOfOrientation_Zup_AxoLeft = V3d_TypeOfOrientation.V3d_TypeOfOrientation_Zup_AxoLeft
V3d_TypeOfOrientation_Zup_AxoRight = V3d_TypeOfOrientation.V3d_TypeOfOrientation_Zup_AxoRight
V3d_TypeOfOrientation_Zup_Front = V3d_TypeOfOrientation.V3d_TypeOfOrientation_Zup_Front
V3d_TypeOfOrientation_Zup_Back = V3d_TypeOfOrientation.V3d_TypeOfOrientation_Zup_Back
V3d_TypeOfOrientation_Zup_Top = V3d_TypeOfOrientation.V3d_TypeOfOrientation_Zup_Top
V3d_TypeOfOrientation_Zup_Bottom = V3d_TypeOfOrientation.V3d_TypeOfOrientation_Zup_Bottom
V3d_TypeOfOrientation_Zup_Left = V3d_TypeOfOrientation.V3d_TypeOfOrientation_Zup_Left
V3d_TypeOfOrientation_Zup_Right = V3d_TypeOfOrientation.V3d_TypeOfOrientation_Zup_Right
V3d_TypeOfOrientation_Yup_AxoLeft = V3d_TypeOfOrientation.V3d_TypeOfOrientation_Yup_AxoLeft
V3d_TypeOfOrientation_Yup_AxoRight = V3d_TypeOfOrientation.V3d_TypeOfOrientation_Yup_AxoRight
V3d_TypeOfOrientation_Yup_Front = V3d_TypeOfOrientation.V3d_TypeOfOrientation_Yup_Front
V3d_TypeOfOrientation_Yup_Back = V3d_TypeOfOrientation.V3d_TypeOfOrientation_Yup_Back
V3d_TypeOfOrientation_Yup_Top = V3d_TypeOfOrientation.V3d_TypeOfOrientation_Yup_Top
V3d_TypeOfOrientation_Yup_Bottom = V3d_TypeOfOrientation.V3d_TypeOfOrientation_Yup_Bottom
V3d_TypeOfOrientation_Yup_Left = V3d_TypeOfOrientation.V3d_TypeOfOrientation_Yup_Left
V3d_TypeOfOrientation_Yup_Right = V3d_TypeOfOrientation.V3d_TypeOfOrientation_Yup_Right

class V3d_TypeOfAxe(IntEnum):
	V3d_X: int = ...
	V3d_Y: int = ...
	V3d_Z: int = ...
V3d_X = V3d_TypeOfAxe.V3d_X
V3d_Y = V3d_TypeOfAxe.V3d_Y
V3d_Z = V3d_TypeOfAxe.V3d_Z

class V3d_TypeOfRepresentation(IntEnum):
	V3d_SIMPLE: int = ...
	V3d_COMPLETE: int = ...
	V3d_PARTIAL: int = ...
	V3d_SAMELAST: int = ...
V3d_SIMPLE = V3d_TypeOfRepresentation.V3d_SIMPLE
V3d_COMPLETE = V3d_TypeOfRepresentation.V3d_COMPLETE
V3d_PARTIAL = V3d_TypeOfRepresentation.V3d_PARTIAL
V3d_SAMELAST = V3d_TypeOfRepresentation.V3d_SAMELAST

class V3d_TypeOfBackfacingModel(IntEnum):
	V3d_TOBM_AUTOMATIC: int = ...
	V3d_TOBM_ALWAYS_DISPLAYED: int = ...
	V3d_TOBM_NEVER_DISPLAYED: int = ...
V3d_TOBM_AUTOMATIC = V3d_TypeOfBackfacingModel.V3d_TOBM_AUTOMATIC
V3d_TOBM_ALWAYS_DISPLAYED = V3d_TypeOfBackfacingModel.V3d_TOBM_ALWAYS_DISPLAYED
V3d_TOBM_NEVER_DISPLAYED = V3d_TypeOfBackfacingModel.V3d_TOBM_NEVER_DISPLAYED

class V3d_TypeOfPickLight(IntEnum):
	V3d_POSITIONLIGHT: int = ...
	V3d_SPACELIGHT: int = ...
	V3d_RADIUSTEXTLIGHT: int = ...
	V3d_ExtRADIUSLIGHT: int = ...
	V3d_IntRADIUSLIGHT: int = ...
	V3d_NOTHING: int = ...
V3d_POSITIONLIGHT = V3d_TypeOfPickLight.V3d_POSITIONLIGHT
V3d_SPACELIGHT = V3d_TypeOfPickLight.V3d_SPACELIGHT
V3d_RADIUSTEXTLIGHT = V3d_TypeOfPickLight.V3d_RADIUSTEXTLIGHT
V3d_ExtRADIUSLIGHT = V3d_TypeOfPickLight.V3d_ExtRADIUSLIGHT
V3d_IntRADIUSLIGHT = V3d_TypeOfPickLight.V3d_IntRADIUSLIGHT
V3d_NOTHING = V3d_TypeOfPickLight.V3d_NOTHING

class v3d:
	@staticmethod
	def ArrowOfRadius(garrow: Graphic3d_Group, X0: float, Y0: float, Z0: float, DX: float, DY: float, DZ: float, Alpha: float, Lng: float) -> None: ...
	@staticmethod
	def CircleInPlane(gcircle: Graphic3d_Group, X0: float, Y0: float, Z0: float, VX: float, VY: float, VZ: float, Radius: float) -> None: ...
	@staticmethod
	def GetProjAxis(theOrientation: V3d_TypeOfOrientation) -> gp_Dir: ...
	@staticmethod
	def SwitchViewsinWindow(aPreviousView: V3d_View, aNextView: V3d_View) -> None: ...
	@overload
	@staticmethod
	def TypeOfOrientationFromString(theTypeString: str) -> V3d_TypeOfOrientation: ...
	@overload
	@staticmethod
	def TypeOfOrientationFromString(theTypeString: str, theType: V3d_TypeOfOrientation) -> bool: ...
	@staticmethod
	def TypeOfOrientationToString(theType: V3d_TypeOfOrientation) -> str: ...

class V3d_AmbientLight(Graphic3d_CLight):
	def __init__(self, theColor: Optional[Quantity_Color] = Quantity_NOC_WHITE) -> None: ...

class V3d_CircularGrid(Aspect_CircularGrid):
	def __init__(self, aViewer: V3d_ViewerPointer, aColor: Quantity_Color, aTenthColor: Quantity_Color) -> None: ...
	def Display(self) -> None: ...
	def Erase(self) -> None: ...
	def GraphicValues(self) -> Tuple[float, float]: ...
	def IsDisplayed(self) -> bool: ...
	def SetColors(self, aColor: Quantity_Color, aTenthColor: Quantity_Color) -> None: ...
	def SetGraphicValues(self, Radius: float, OffSet: float) -> None: ...

class V3d_ImageDumpOptions:
	def __init__(self) -> None: ...

class V3d_Plane(Standard_Transient):
	def __init__(self, theA: Optional[float] = 0.0, theB: Optional[float] = 0.0, theC: Optional[float] = 1.0, theD: Optional[float] = 0.0) -> None: ...
	def ClipPlane(self) -> Graphic3d_ClipPlane: ...
	def Display(self, theView: V3d_View, theColor: Optional[Quantity_Color] = Quantity_NOC_GRAY) -> None: ...
	def Erase(self) -> None: ...
	def IsDisplayed(self) -> bool: ...
	def Plane(self) -> Tuple[float, float, float, float]: ...
	def SetPlane(self, theA: float, theB: float, theC: float, theD: float) -> None: ...

class V3d_PositionLight(Graphic3d_CLight):
	pass

class V3d_RectangularGrid(Aspect_RectangularGrid):
	def __init__(self, aViewer: V3d_ViewerPointer, aColor: Quantity_Color, aTenthColor: Quantity_Color) -> None: ...
	def Display(self) -> None: ...
	def Erase(self) -> None: ...
	def GraphicValues(self) -> Tuple[float, float, float]: ...
	def IsDisplayed(self) -> bool: ...
	def SetColors(self, aColor: Quantity_Color, aTenthColor: Quantity_Color) -> None: ...
	def SetGraphicValues(self, XSize: float, YSize: float, OffSet: float) -> None: ...

class V3d_Trihedron(Standard_Transient):
	def __init__(self) -> None: ...
	def Display(self, theView: V3d_View) -> None: ...
	def Erase(self) -> None: ...
	def SetArrowDiameter(self, theDiam: float) -> None: ...
	def SetArrowsColor(self, theXColor: Quantity_Color, theYColor: Quantity_Color, theZColor: Quantity_Color) -> None: ...
	def SetLabelsColor(self, theColor: Quantity_Color) -> None: ...
	def SetNbFacets(self, theNbFacets: int) -> None: ...
	def SetPosition(self, thePosition: Aspect_TypeOfTriedronPosition) -> None: ...
	def SetScale(self, theScale: float) -> None: ...
	def SetSizeRatio(self, theRatio: float) -> None: ...
	def SetWireframe(self, theAsWireframe: bool) -> None: ...

class V3d_View(Standard_Transient):
	@overload
	def __init__(self, theViewer: V3d_Viewer, theType: Optional[V3d_TypeOfView] = V3d_ORTHOGRAPHIC) -> None: ...
	@overload
	def __init__(self, theViewer: V3d_Viewer, theView: V3d_View) -> None: ...
	def ActiveLight(self) -> V3d_Light: ...
	def ActiveLightIterator(self) -> V3d_ListOfLightIterator: ...
	def ActiveLights(self) -> V3d_ListOfLight: ...
	def AddClipPlane(self, thePlane: Graphic3d_ClipPlane) -> None: ...
	def At(self) -> Tuple[float, float, float]: ...
	def AutoZFit(self) -> None: ...
	def AutoZFitMode(self) -> bool: ...
	def AutoZFitScaleFactor(self) -> float: ...
	@overload
	def AxialScale(self) -> Tuple[float, float, float]: ...
	@overload
	def AxialScale(self, Dx: int, Dy: int, Axis: V3d_TypeOfAxe) -> None: ...
	def BackFacingModel(self) -> V3d_TypeOfBackfacingModel: ...
	@overload
	def BackgroundColor(self, Type: Quantity_TypeOfColor) -> Tuple[float, float, float]: ...
	@overload
	def BackgroundColor(self) -> Quantity_Color: ...
	def Camera(self) -> Graphic3d_Camera: ...
	def ChangeRenderingParams(self) -> Graphic3d_RenderingParams: ...
	def ClearPBREnvironment(self, theToUpdate: Optional[bool] = False) -> None: ...
	def ClipPlanes(self) -> Graphic3d_SequenceOfHClipPlane: ...
	def ComputedMode(self) -> bool: ...
	@overload
	def Convert(self, Vp: int) -> float: ...
	@overload
	def Convert(self, Xp: int, Yp: int) -> Tuple[float, float]: ...
	@overload
	def Convert(self, Vv: float) -> int: ...
	@overload
	def Convert(self, Xv: float, Yv: float) -> Tuple[int, int]: ...
	@overload
	def Convert(self, Xp: int, Yp: int) -> Tuple[float, float, float]: ...
	@overload
	def Convert(self, X: float, Y: float, Z: float) -> Tuple[int, int]: ...
	@overload
	def ConvertToGrid(self, Xp: int, Yp: int) -> Tuple[float, float, float]: ...
	@overload
	def ConvertToGrid(self, X: float, Y: float, Z: float) -> Tuple[float, float, float]: ...
	def ConvertWithProj(self, Xp: int, Yp: int) -> Tuple[float, float, float, float, float, float]: ...
	def DefaultCamera(self) -> Graphic3d_Camera: ...
	def Depth(self) -> float: ...
	def DepthFitAll(self, Aspect: Optional[float] = 0.01, Margin: Optional[float] = 0.01) -> None: ...
	def DiagnosticInformation(self, theDict: TColStd_IndexedDataMapOfStringString, theFlags: Graphic3d_DiagnosticInfo) -> None: ...
	def DoMapping(self) -> None: ...
	def Dump(self, theFile: str, theBufferType: Optional[Graphic3d_BufferType] = Graphic3d_BT_RGB) -> bool: ...
	def Eye(self) -> Tuple[float, float, float]: ...
	@overload
	def FitAll(self, theMargin: Optional[float] = 0.01, theToUpdate: Optional[bool] = True) -> None: ...
	@overload
	def FitAll(self, theBox: Bnd_Box, theMargin: Optional[float] = 0.01, theToUpdate: Optional[bool] = True) -> None: ...
	@overload
	def FitAll(self, theMinXv: float, theMinYv: float, theMaxXv: float, theMaxYv: float) -> None: ...
	def FitMinMax(self, theCamera: Graphic3d_Camera, theBox: Bnd_Box, theMargin: float, theResolution: Optional[float] = 0.0, theToEnlargeIfLine: Optional[bool] = True) -> bool: ...
	def FocalReferencePoint(self) -> Tuple[float, float, float]: ...
	def Focale(self) -> float: ...
	def GeneratePBREnvironment(self, theToUpdate: Optional[bool] = False) -> None: ...
	def GetGraduatedTrihedron(self) -> Graphic3d_GraduatedTrihedron: ...
	def GradientBackground(self) -> Aspect_GradientBackground: ...
	def GradientBackgroundColors(self, theColor1: Quantity_Color, theColor2: Quantity_Color) -> None: ...
	def GraduatedTrihedronDisplay(self, theTrihedronData: Graphic3d_GraduatedTrihedron) -> None: ...
	def GraduatedTrihedronErase(self) -> None: ...
	def GravityPoint(self) -> gp_Pnt: ...
	def IfMoreLights(self) -> bool: ...
	def IfWindow(self) -> bool: ...
	def InitActiveLights(self) -> None: ...
	def Invalidate(self) -> None: ...
	def InvalidateImmediate(self) -> None: ...
	def IsActiveLight(self, theLight: V3d_Light) -> bool: ...
	def IsCullingEnabled(self) -> bool: ...
	def IsEmpty(self) -> bool: ...
	def IsInvalidated(self) -> bool: ...
	def IsInvalidatedImmediate(self) -> bool: ...
	def LightLimit(self) -> int: ...
	def MoreActiveLights(self) -> bool: ...
	@overload
	def Move(self, Dx: float, Dy: float, Dz: float, Start: Optional[bool] = True) -> None: ...
	@overload
	def Move(self, Axe: V3d_TypeOfAxe, Length: float, Start: Optional[bool] = True) -> None: ...
	@overload
	def Move(self, Length: float, Start: Optional[bool] = True) -> None: ...
	def MustBeResized(self) -> None: ...
	def NextActiveLights(self) -> None: ...
	def Pan(self, theDXp: int, theDYp: int, theZoomFactor: Optional[float] = 1, theToStart: Optional[bool] = True) -> None: ...
	def Panning(self, theDXv: float, theDYv: float, theZoomFactor: Optional[float] = 1, theToStart: Optional[bool] = True) -> None: ...
	def Place(self, theXp: int, theYp: int, theZoomFactor: Optional[float] = 1) -> None: ...
	def PlaneLimit(self) -> int: ...
	def Proj(self) -> Tuple[float, float, float]: ...
	def ProjReferenceAxe(self, Xpix: int, Ypix: int) -> Tuple[float, float, float, float, float, float]: ...
	@overload
	def Project(self, theX: float, theY: float, theZ: float) -> Tuple[float, float]: ...
	@overload
	def Project(self, theX: float, theY: float, theZ: float) -> Tuple[float, float, float]: ...
	def Redraw(self) -> None: ...
	def RedrawImmediate(self) -> None: ...
	def Remove(self) -> None: ...
	def RemoveClipPlane(self, thePlane: Graphic3d_ClipPlane) -> None: ...
	def RenderingParams(self) -> Graphic3d_RenderingParams: ...
	def Reset(self, theToUpdate: Optional[bool] = True) -> None: ...
	def ResetViewMapping(self) -> None: ...
	def ResetViewOrientation(self) -> None: ...
	@overload
	def Rotate(self, Ax: float, Ay: float, Az: float, Start: Optional[bool] = True) -> None: ...
	@overload
	def Rotate(self, Ax: float, Ay: float, Az: float, X: float, Y: float, Z: float, Start: Optional[bool] = True) -> None: ...
	@overload
	def Rotate(self, Axe: V3d_TypeOfAxe, Angle: float, X: float, Y: float, Z: float, Start: Optional[bool] = True) -> None: ...
	@overload
	def Rotate(self, Axe: V3d_TypeOfAxe, Angle: float, Start: Optional[bool] = True) -> None: ...
	@overload
	def Rotate(self, Angle: float, Start: Optional[bool] = True) -> None: ...
	def Rotation(self, X: int, Y: int) -> None: ...
	def Scale(self) -> float: ...
	def SetAt(self, X: float, Y: float, Z: float) -> None: ...
	def SetAutoZFitMode(self, theIsOn: bool, theScaleFactor: Optional[float] = 1.0) -> None: ...
	def SetAxialScale(self, Sx: float, Sy: float, Sz: float) -> None: ...
	def SetAxis(self, X: float, Y: float, Z: float, Vx: float, Vy: float, Vz: float) -> None: ...
	def SetBackFacingModel(self, theModel: Optional[V3d_TypeOfBackfacingModel] = V3d_TOBM_AUTOMATIC) -> None: ...
	@overload
	def SetBackgroundColor(self, theType: Quantity_TypeOfColor, theV1: float, theV2: float, theV3: float) -> None: ...
	@overload
	def SetBackgroundColor(self, theColor: Quantity_Color) -> None: ...
	def SetBackgroundCubeMap(self, theCubeMap: Graphic3d_CubeMap, theToUpdatePBREnv: Optional[bool] = True, theToUpdate: Optional[bool] = False) -> None: ...
	@overload
	def SetBackgroundImage(self, theFileName: str, theFillStyle: Optional[Aspect_FillMethod] = Aspect_FM_CENTERED, theToUpdate: Optional[bool] = False) -> None: ...
	@overload
	def SetBackgroundImage(self, theTexture: Graphic3d_Texture2D, theFillStyle: Optional[Aspect_FillMethod] = Aspect_FM_CENTERED, theToUpdate: Optional[bool] = False) -> None: ...
	def SetBgGradientColors(self, theColor1: Quantity_Color, theColor2: Quantity_Color, theFillStyle: Optional[Aspect_GradientFillMethod] = Aspect_GFM_HOR, theToUpdate: Optional[bool] = False) -> None: ...
	def SetBgGradientStyle(self, theMethod: Optional[Aspect_GradientFillMethod] = Aspect_GFM_HOR, theToUpdate: Optional[bool] = False) -> None: ...
	def SetBgImageStyle(self, theFillStyle: Aspect_FillMethod, theToUpdate: Optional[bool] = False) -> None: ...
	def SetCamera(self, theCamera: Graphic3d_Camera) -> None: ...
	def SetCenter(self, theXp: int, theYp: int) -> None: ...
	@overload
	def SetClipPlanes(self, thePlanes: Graphic3d_SequenceOfHClipPlane) -> None: ...
	@overload
	def SetClipPlanes(self, thePlanes: Graphic3d_SequenceOfHClipPlane) -> None: ...
	def SetComputedMode(self, theMode: bool) -> None: ...
	def SetDepth(self, Depth: float) -> None: ...
	def SetEye(self, X: float, Y: float, Z: float) -> None: ...
	def SetFocale(self, Focale: float) -> None: ...
	def SetFront(self) -> None: ...
	def SetFrustumCulling(self, theMode: bool) -> None: ...
	def SetGrid(self, aPlane: gp_Ax3, aGrid: Aspect_Grid) -> None: ...
	def SetGridActivity(self, aFlag: bool) -> None: ...
	def SetImmediateUpdate(self, theImmediateUpdate: bool) -> bool: ...
	@overload
	def SetLightOff(self, theLight: V3d_Light) -> None: ...
	@overload
	def SetLightOff(self) -> None: ...
	@overload
	def SetLightOn(self, theLight: V3d_Light) -> None: ...
	@overload
	def SetLightOn(self) -> None: ...
	def SetMagnify(self, theWindow: Aspect_Window, thePreviousView: V3d_View, theX1: int, theY1: int, theX2: int, theY2: int) -> None: ...
	@overload
	def SetProj(self, Vx: float, Vy: float, Vz: float) -> None: ...
	@overload
	def SetProj(self, theOrientation: V3d_TypeOfOrientation, theIsYup: Optional[bool] = False) -> None: ...
	def SetScale(self, Coef: float) -> None: ...
	def SetShadingModel(self, theShadingModel: Graphic3d_TypeOfShadingModel) -> None: ...
	def SetSize(self, theSize: float) -> None: ...
	def SetTextureEnv(self, theTexture: Graphic3d_TextureEnv) -> None: ...
	def SetTwist(self, Angle: float) -> None: ...
	@overload
	def SetUp(self, Vx: float, Vy: float, Vz: float) -> None: ...
	@overload
	def SetUp(self, Orientation: V3d_TypeOfOrientation) -> None: ...
	def SetViewMappingDefault(self) -> None: ...
	def SetViewOrientationDefault(self) -> None: ...
	def SetVisualization(self, theType: V3d_TypeOfVisualization) -> None: ...
	def SetWindow(self, theWindow: Aspect_Window, theContext: Optional[Aspect_RenderingContext] = None) -> None: ...
	def SetZSize(self, SetZSize: float) -> None: ...
	def SetZoom(self, Coef: float, Start: Optional[bool] = True) -> None: ...
	def ShadingModel(self) -> Graphic3d_TypeOfShadingModel: ...
	def Size(self) -> Tuple[float, float]: ...
	def StartRotation(self, X: int, Y: int, zRotationThreshold: Optional[float] = 0.0) -> None: ...
	def StartZoomAtPoint(self, theXp: int, theYp: int) -> None: ...
	@overload
	def StatisticInformation(self) -> TCollection_AsciiString: ...
	@overload
	def StatisticInformation(self, theDict: TColStd_IndexedDataMapOfStringString) -> None: ...
	def TextureEnv(self) -> Graphic3d_TextureEnv: ...
	@overload
	def ToPixMap(self, theImage: Image_PixMap, theParams: V3d_ImageDumpOptions) -> bool: ...
	@overload
	def ToPixMap(self, theImage: Image_PixMap, theWidth: int, theHeight: int, theBufferType: Optional[Graphic3d_BufferType] = Graphic3d_BT_RGB, theToAdjustAspect: Optional[bool] = True, theStereoOptions: Optional[V3d_StereoDumpOptions] = V3d_SDO_MONO) -> bool: ...
	@overload
	def Translate(self, Dx: float, Dy: float, Dz: float, Start: Optional[bool] = True) -> None: ...
	@overload
	def Translate(self, Axe: V3d_TypeOfAxe, Length: float, Start: Optional[bool] = True) -> None: ...
	@overload
	def Translate(self, Length: float, Start: Optional[bool] = True) -> None: ...
	def TriedronDisplay(self, thePosition: Optional[Aspect_TypeOfTriedronPosition] = Aspect_TOTP_CENTER, theColor: Optional[Quantity_Color] = Quantity_NOC_WHITE, theScale: Optional[float] = 0.02, theMode: Optional[V3d_TypeOfVisualization] = V3d_WIREFRAME) -> None: ...
	def TriedronErase(self) -> None: ...
	@overload
	def Turn(self, Ax: float, Ay: float, Az: float, Start: Optional[bool] = True) -> None: ...
	@overload
	def Turn(self, Axe: V3d_TypeOfAxe, Angle: float, Start: Optional[bool] = True) -> None: ...
	@overload
	def Turn(self, Angle: float, Start: Optional[bool] = True) -> None: ...
	def Twist(self) -> float: ...
	def Type(self) -> V3d_TypeOfView: ...
	def Up(self) -> Tuple[float, float, float]: ...
	def Update(self) -> None: ...
	def UpdateLights(self) -> None: ...
	def View(self) -> Graphic3d_CView: ...
	def Viewer(self) -> V3d_Viewer: ...
	def Visualization(self) -> V3d_TypeOfVisualization: ...
	def Window(self) -> Aspect_Window: ...
	def WindowFit(self, theMinXp: int, theMinYp: int, theMaxXp: int, theMaxYp: int) -> None: ...
	def WindowFitAll(self, Xmin: int, Ymin: int, Xmax: int, Ymax: int) -> None: ...
	def ZBufferTriedronSetup(self, theXColor: Optional[Quantity_Color] = Quantity_NOC_RED, theYColor: Optional[Quantity_Color] = Quantity_NOC_GREEN, theZColor: Optional[Quantity_Color] = Quantity_NOC_BLUE1, theSizeRatio: Optional[float] = 0.8, theAxisDiametr: Optional[float] = 0.05, theNbFacettes: Optional[int] = 12) -> None: ...
	def ZFitAll(self, theScaleFactor: Optional[float] = 1.0) -> None: ...
	def ZSize(self) -> float: ...
	def Zoom(self, theXp1: int, theYp1: int, theXp2: int, theYp2: int) -> None: ...
	def ZoomAtPoint(self, theMouseStartX: int, theMouseStartY: int, theMouseEndX: int, theMouseEndY: int) -> None: ...

class V3d_Viewer(Standard_Transient):
	@overload
	def __init__(self, theDriver: Graphic3d_GraphicDriver) -> None: ...
	@overload
	def __init__(self, theDriver: Graphic3d_GraphicDriver, theName: Standard_ExtString, theDomain: Optional[str] = "", theViewSize: Optional[float] = 1000.0, theViewProj: Optional[V3d_TypeOfOrientation] = V3d_XposYnegZpos, theViewBackground: Optional[Quantity_Color] = Quantity_NOC_GRAY30, theVisualization: Optional[V3d_TypeOfVisualization] = V3d_ZBUFFER, theShadingModel: Optional[Graphic3d_TypeOfShadingModel] = Graphic3d_TOSM_VERTEX, theComputedMode: Optional[bool] = True, theDefaultComputedMode: Optional[bool] = True) -> None: ...
	def ActivateGrid(self, aGridType: Aspect_GridType, aGridDrawMode: Aspect_GridDrawMode) -> None: ...
	def ActiveLight(self) -> V3d_Light: ...
	def ActiveLightIterator(self) -> V3d_ListOfLightIterator: ...
	def ActiveLights(self) -> V3d_ListOfLight: ...
	def ActiveView(self) -> V3d_View: ...
	def ActiveViewIterator(self) -> V3d_ListOfViewIterator: ...
	def ActiveViews(self) -> V3d_ListOfView: ...
	def AddLight(self, theLight: V3d_Light) -> None: ...
	def AddZLayer(self, theSettings: Optional[Graphic3d_ZLayerSettings] = Graphic3d_ZLayerSettings()) -> Tuple[bool, int]: ...
	def CircularGridGraphicValues(self) -> Tuple[float, float]: ...
	def CircularGridValues(self) -> Tuple[float, float, float, int, float]: ...
	def ComputedMode(self) -> bool: ...
	def CreateView(self) -> V3d_View: ...
	def DeactivateGrid(self) -> None: ...
	@overload
	def DefaultBackgroundColor(self) -> Quantity_Color: ...
	@overload
	def DefaultBackgroundColor(self, theType: Quantity_TypeOfColor) -> Tuple[float, float, float]: ...
	def DefaultBgGradientColors(self, theColor1: Quantity_Color, theColor2: Quantity_Color) -> None: ...
	def DefaultComputedMode(self) -> bool: ...
	def DefaultRenderingParams(self) -> Graphic3d_RenderingParams: ...
	def DefaultShadingModel(self) -> Graphic3d_TypeOfShadingModel: ...
	def DefaultTypeOfView(self) -> V3d_TypeOfView: ...
	def DefaultViewProj(self) -> V3d_TypeOfOrientation: ...
	def DefaultViewSize(self) -> float: ...
	def DefaultVisualization(self) -> V3d_TypeOfVisualization: ...
	def DefinedLight(self) -> V3d_Light: ...
	def DefinedLightIterator(self) -> V3d_ListOfLightIterator: ...
	def DefinedLights(self) -> V3d_ListOfLight: ...
	def DefinedView(self) -> V3d_View: ...
	def DefinedViewIterator(self) -> V3d_ListOfViewIterator: ...
	def DefinedViews(self) -> V3d_ListOfView: ...
	def DelLight(self, theLight: V3d_Light) -> None: ...
	def DisplayPrivilegedPlane(self, theOnOff: bool, theSize: Optional[float] = 1) -> None: ...
	def Driver(self) -> Graphic3d_GraphicDriver: ...
	def Erase(self) -> None: ...
	def GetAllZLayers(self, theLayerSeq: TColStd_SequenceOfInteger) -> None: ...
	def GetGradientBackground(self) -> Aspect_GradientBackground: ...
	def Grid(self) -> Aspect_Grid: ...
	def GridDrawMode(self) -> Aspect_GridDrawMode: ...
	def GridEcho(self) -> bool: ...
	def GridType(self) -> Aspect_GridType: ...
	def HideGridEcho(self, theView: V3d_View) -> None: ...
	def IfMoreViews(self) -> bool: ...
	def InitActiveLights(self) -> None: ...
	def InitActiveViews(self) -> None: ...
	def InitDefinedLights(self) -> None: ...
	def InitDefinedViews(self) -> None: ...
	def Invalidate(self) -> None: ...
	def IsActive(self) -> bool: ...
	def IsGlobalLight(self, TheLight: V3d_Light) -> bool: ...
	def LastActiveView(self) -> bool: ...
	def MoreActiveLights(self) -> bool: ...
	def MoreActiveViews(self) -> bool: ...
	def MoreDefinedLights(self) -> bool: ...
	def MoreDefinedViews(self) -> bool: ...
	def NextActiveLights(self) -> None: ...
	def NextActiveViews(self) -> None: ...
	def NextDefinedLights(self) -> None: ...
	def NextDefinedViews(self) -> None: ...
	def PrivilegedPlane(self) -> gp_Ax3: ...
	def RectangularGridGraphicValues(self) -> Tuple[float, float, float]: ...
	def RectangularGridValues(self) -> Tuple[float, float, float, float, float]: ...
	def Redraw(self) -> None: ...
	def RedrawImmediate(self) -> None: ...
	def Remove(self) -> None: ...
	def SetCircularGridGraphicValues(self, Radius: float, OffSet: float) -> None: ...
	def SetCircularGridValues(self, XOrigin: float, YOrigin: float, RadiusStep: float, DivisionNumber: int, RotationAngle: float) -> None: ...
	def SetComputedMode(self, theMode: bool) -> None: ...
	@overload
	def SetDefaultBackgroundColor(self, theColor: Quantity_Color) -> None: ...
	@overload
	def SetDefaultBackgroundColor(self, theType: Quantity_TypeOfColor, theV1: float, theV2: float, theV3: float) -> None: ...
	def SetDefaultBgGradientColors(self, theColor1: Quantity_Color, theColor2: Quantity_Color, theFillStyle: Optional[Aspect_GradientFillMethod] = Aspect_GFM_HOR) -> None: ...
	def SetDefaultComputedMode(self, theMode: bool) -> None: ...
	def SetDefaultLights(self) -> None: ...
	def SetDefaultRenderingParams(self, theParams: Graphic3d_RenderingParams) -> None: ...
	def SetDefaultShadingModel(self, theType: Graphic3d_TypeOfShadingModel) -> None: ...
	def SetDefaultTypeOfView(self, theType: V3d_TypeOfView) -> None: ...
	def SetDefaultViewProj(self, theOrientation: V3d_TypeOfOrientation) -> None: ...
	def SetDefaultViewSize(self, theSize: float) -> None: ...
	def SetDefaultVisualization(self, theType: V3d_TypeOfVisualization) -> None: ...
	@overload
	def SetGridEcho(self, showGrid: Optional[bool] = True) -> None: ...
	@overload
	def SetGridEcho(self, aMarker: Graphic3d_AspectMarker3d) -> None: ...
	@overload
	def SetLightOff(self, theLight: V3d_Light) -> None: ...
	@overload
	def SetLightOff(self) -> None: ...
	@overload
	def SetLightOn(self, theLight: V3d_Light) -> None: ...
	@overload
	def SetLightOn(self) -> None: ...
	def SetPrivilegedPlane(self, thePlane: gp_Ax3) -> None: ...
	def SetRectangularGridGraphicValues(self, XSize: float, YSize: float, OffSet: float) -> None: ...
	def SetRectangularGridValues(self, XOrigin: float, YOrigin: float, XStep: float, YStep: float, RotationAngle: float) -> None: ...
	@overload
	def SetViewOff(self) -> None: ...
	@overload
	def SetViewOff(self, theView: V3d_View) -> None: ...
	@overload
	def SetViewOn(self) -> None: ...
	@overload
	def SetViewOn(self, theView: V3d_View) -> None: ...
	def ShowGridEcho(self, theView: V3d_View, thePoint: Graphic3d_Vertex) -> None: ...
	def StructureManager(self) -> Graphic3d_StructureManager: ...
	def UnHighlight(self) -> None: ...
	def Update(self) -> None: ...
	def UpdateLights(self) -> None: ...

class V3d_DirectionalLight(V3d_PositionLight):
	@overload
	def __init__(self, theDirection: Optional[V3d_TypeOfOrientation] = V3d_XposYposZpos, theColor: Optional[Quantity_Color] = Quantity_NOC_WHITE, theIsHeadlight: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, theDirection: gp_Dir, theColor: Optional[Quantity_Color] = Quantity_NOC_WHITE, theIsHeadlight: Optional[bool] = False) -> None: ...
	def SetDirection(self, theDirection: V3d_TypeOfOrientation) -> None: ...

class V3d_PositionalLight(V3d_PositionLight):
	def __init__(self, thePos: gp_Pnt, theColor: Optional[Quantity_Color] = Quantity_NOC_WHITE) -> None: ...

class V3d_SpotLight(V3d_PositionLight):
	@overload
	def __init__(self, thePos: gp_Pnt, theDirection: Optional[V3d_TypeOfOrientation] = V3d_XnegYnegZpos, theColor: Optional[Quantity_Color] = Quantity_NOC_WHITE) -> None: ...
	@overload
	def __init__(self, thePos: gp_Pnt, theDirection: gp_Dir, theColor: Optional[Quantity_Color] = Quantity_NOC_WHITE) -> None: ...
	def SetDirection(self, theOrientation: V3d_TypeOfOrientation) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

v3d_ArrowOfRadius = v3d.ArrowOfRadius
v3d_CircleInPlane = v3d.CircleInPlane
v3d_GetProjAxis = v3d.GetProjAxis
v3d_SwitchViewsinWindow = v3d.SwitchViewsinWindow
v3d_TypeOfOrientationFromString = v3d.TypeOfOrientationFromString
v3d_TypeOfOrientationFromString = v3d.TypeOfOrientationFromString
v3d_TypeOfOrientationToString = v3d.TypeOfOrientationToString



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *
from OCC.Core.Plate import *
from OCC.Core.Geom import *


class NLPlate_SequenceOfHGPPConstraint:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class NLPlate_StackOfPlate:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> Plate_Plate: ...
    def Last(self) -> Plate_Plate: ...
    def Append(self, theItem: Plate_Plate) -> Plate_Plate: ...
    def Prepend(self, theItem: Plate_Plate) -> Plate_Plate: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> Plate_Plate: ...
    def SetValue(self, theIndex: int, theValue: Plate_Plate) -> None: ...

class NLPlate_HGPPConstraint(Standard_Transient):
	def ActiveOrder(self) -> int: ...
	def G0Criterion(self) -> float: ...
	def G0Target(self) -> gp_XYZ: ...
	def G1Criterion(self) -> float: ...
	def G1Target(self) -> Plate_D1: ...
	def G2Criterion(self) -> float: ...
	def G2Target(self) -> Plate_D2: ...
	def G3Criterion(self) -> float: ...
	def G3Target(self) -> Plate_D3: ...
	def IncrementalLoadAllowed(self) -> bool: ...
	def IsG0(self) -> bool: ...
	def Orientation(self) -> int: ...
	def SetActiveOrder(self, ActiveOrder: int) -> None: ...
	def SetG0Criterion(self, TolDist: float) -> None: ...
	def SetG1Criterion(self, TolAng: float) -> None: ...
	def SetG2Criterion(self, TolCurv: float) -> None: ...
	def SetG3Criterion(self, TolG3: float) -> None: ...
	def SetIncrementalLoadAllowed(self, ILA: bool) -> None: ...
	def SetOrientation(self, Orient: Optional[int] = 0) -> None: ...
	def SetUV(self, UV: gp_XY) -> None: ...
	def SetUVFreeSliding(self, UVFree: bool) -> None: ...
	def UV(self) -> gp_XY: ...
	def UVFreeSliding(self) -> bool: ...

class NLPlate_NLPlate:
	def __init__(self, InitialSurface: Geom_Surface) -> None: ...
	def ConstraintsSliding(self, NbIterations: Optional[int] = 3) -> None: ...
	def Continuity(self) -> int: ...
	def Evaluate(self, point2d: gp_XY) -> gp_XYZ: ...
	def EvaluateDerivative(self, point2d: gp_XY, iu: int, iv: int) -> gp_XYZ: ...
	def IncrementalSolve(self, ord: Optional[int] = 2, InitialConsraintOrder: Optional[int] = 1, NbIncrements: Optional[int] = 4, UVSliding: Optional[bool] = False) -> None: ...
	def Init(self) -> None: ...
	def IsDone(self) -> bool: ...
	def Load(self, GConst: NLPlate_HGPPConstraint) -> None: ...
	def MaxActiveConstraintOrder(self) -> int: ...
	def Solve(self, ord: Optional[int] = 2, InitialConsraintOrder: Optional[int] = 1) -> None: ...
	def Solve2(self, ord: Optional[int] = 2, InitialConsraintOrder: Optional[int] = 1) -> None: ...
	def destroy(self) -> None: ...

class NLPlate_HPG0Constraint(NLPlate_HGPPConstraint):
	def __init__(self, UV: gp_XY, Value: gp_XYZ) -> None: ...
	def ActiveOrder(self) -> int: ...
	def G0Target(self) -> gp_XYZ: ...
	def IncrementalLoadAllowed(self) -> bool: ...
	def IsG0(self) -> bool: ...
	def SetIncrementalLoadAllowed(self, ILA: bool) -> None: ...
	def SetUVFreeSliding(self, UVFree: bool) -> None: ...
	def UVFreeSliding(self) -> bool: ...

class NLPlate_HPG1Constraint(NLPlate_HGPPConstraint):
	def __init__(self, UV: gp_XY, D1T: Plate_D1) -> None: ...
	def ActiveOrder(self) -> int: ...
	def G1Target(self) -> Plate_D1: ...
	def IncrementalLoadAllowed(self) -> bool: ...
	def IsG0(self) -> bool: ...
	def Orientation(self) -> int: ...
	def SetIncrementalLoadAllowed(self, ILA: bool) -> None: ...
	def SetOrientation(self, Orient: Optional[int] = 0) -> None: ...

class NLPlate_HPG0G1Constraint(NLPlate_HPG0Constraint):
	def __init__(self, UV: gp_XY, Value: gp_XYZ, D1T: Plate_D1) -> None: ...
	def ActiveOrder(self) -> int: ...
	def G1Target(self) -> Plate_D1: ...
	def Orientation(self) -> int: ...
	def SetOrientation(self, Orient: Optional[int] = 0) -> None: ...

class NLPlate_HPG2Constraint(NLPlate_HPG1Constraint):
	def __init__(self, UV: gp_XY, D1T: Plate_D1, D2T: Plate_D2) -> None: ...
	def ActiveOrder(self) -> int: ...
	def G2Target(self) -> Plate_D2: ...

class NLPlate_HPG0G2Constraint(NLPlate_HPG0G1Constraint):
	def __init__(self, UV: gp_XY, Value: gp_XYZ, D1T: Plate_D1, D2T: Plate_D2) -> None: ...
	def ActiveOrder(self) -> int: ...
	def G2Target(self) -> Plate_D2: ...

class NLPlate_HPG3Constraint(NLPlate_HPG2Constraint):
	def __init__(self, UV: gp_XY, D1T: Plate_D1, D2T: Plate_D2, D3T: Plate_D3) -> None: ...
	def ActiveOrder(self) -> int: ...
	def G3Target(self) -> Plate_D3: ...

class NLPlate_HPG0G3Constraint(NLPlate_HPG0G2Constraint):
	def __init__(self, UV: gp_XY, Value: gp_XYZ, D1T: Plate_D1, D2T: Plate_D2, D3T: Plate_D3) -> None: ...
	def ActiveOrder(self) -> int: ...
	def G3Target(self) -> Plate_D3: ...

# harray1 classes
# harray2 classes
# hsequence classes




# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
LProp module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_lprop.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _LProp
else:
    import _LProp

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _LProp.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _LProp.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _LProp.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _LProp.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _LProp.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _LProp.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _LProp.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _LProp.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _LProp.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _LProp.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _LProp.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _LProp.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _LProp.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _LProp.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _LProp.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _LProp.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _LProp.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _LProp:
_LProp.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _LProp.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.GeomAbs

from enum import IntEnum
from OCC.Core.Exception import *

LProp_Undecided = _LProp.LProp_Undecided
LProp_Undefined = _LProp.LProp_Undefined
LProp_Defined = _LProp.LProp_Defined
LProp_Computed = _LProp.LProp_Computed
LProp_Inflection = _LProp.LProp_Inflection
LProp_MinCur = _LProp.LProp_MinCur
LProp_MaxCur = _LProp.LProp_MaxCur


class LProp_Status(IntEnum):
	LProp_Undecided = 0
	LProp_Undefined = 1
	LProp_Defined = 2
	LProp_Computed = 3
LProp_Undecided = LProp_Status.LProp_Undecided
LProp_Undefined = LProp_Status.LProp_Undefined
LProp_Defined = LProp_Status.LProp_Defined
LProp_Computed = LProp_Status.LProp_Computed

class LProp_CIType(IntEnum):
	LProp_Inflection = 0
	LProp_MinCur = 1
	LProp_MaxCur = 2
LProp_Inflection = LProp_CIType.LProp_Inflection
LProp_MinCur = LProp_CIType.LProp_MinCur
LProp_MaxCur = LProp_CIType.LProp_MaxCur

class LProp_SequenceOfCIType(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< enum LProp_CIType >::iterator":
        return _LProp.LProp_SequenceOfCIType_begin(self)

    def end(self) -> "NCollection_Sequence< enum LProp_CIType >::iterator":
        return _LProp.LProp_SequenceOfCIType_end(self)

    def cbegin(self) -> "NCollection_Sequence< enum LProp_CIType >::const_iterator":
        return _LProp.LProp_SequenceOfCIType_cbegin(self)

    def cend(self) -> "NCollection_Sequence< enum LProp_CIType >::const_iterator":
        return _LProp.LProp_SequenceOfCIType_cend(self)

    def __init__(self, *args):
        _LProp.LProp_SequenceOfCIType_swiginit(self, _LProp.new_LProp_SequenceOfCIType(*args))

    def Size(self) -> "Standard_Integer":
        return _LProp.LProp_SequenceOfCIType_Size(self)

    def Length(self) -> "Standard_Integer":
        return _LProp.LProp_SequenceOfCIType_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _LProp.LProp_SequenceOfCIType_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _LProp.LProp_SequenceOfCIType_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _LProp.LProp_SequenceOfCIType_IsEmpty(self)

    def Reverse(self) -> "void":
        return _LProp.LProp_SequenceOfCIType_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _LProp.LProp_SequenceOfCIType_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _LProp.LProp_SequenceOfCIType_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _LProp.LProp_SequenceOfCIType_Clear(self, theAllocator)

    def Assign(self, theOther: "LProp_SequenceOfCIType") -> "NCollection_Sequence< LProp_CIType > &":
        return _LProp.LProp_SequenceOfCIType_Assign(self, theOther)

    def Set(self, theOther: "LProp_SequenceOfCIType") -> "NCollection_Sequence< LProp_CIType > &":
        return _LProp.LProp_SequenceOfCIType_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _LProp.LProp_SequenceOfCIType_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _LProp.LProp_SequenceOfCIType_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _LProp.LProp_SequenceOfCIType_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _LProp.LProp_SequenceOfCIType_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _LProp.LProp_SequenceOfCIType_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "LProp_SequenceOfCIType") -> "void":
        return _LProp.LProp_SequenceOfCIType_Split(self, theIndex, theSeq)

    def First(self) -> "LProp_CIType const &":
        return _LProp.LProp_SequenceOfCIType_First(self)

    def ChangeFirst(self) -> "LProp_CIType &":
        return _LProp.LProp_SequenceOfCIType_ChangeFirst(self)

    def Last(self) -> "LProp_CIType const &":
        return _LProp.LProp_SequenceOfCIType_Last(self)

    def ChangeLast(self) -> "LProp_CIType &":
        return _LProp.LProp_SequenceOfCIType_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "LProp_CIType const &":
        return _LProp.LProp_SequenceOfCIType_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "LProp_CIType &":
        return _LProp.LProp_SequenceOfCIType_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "LProp_CIType &":
        return _LProp.LProp_SequenceOfCIType___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "LProp_CIType const &") -> "void":
        return _LProp.LProp_SequenceOfCIType_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _LProp.delete_LProp_SequenceOfCIType

    def __len__(self):
        return self.Size()


# Register LProp_SequenceOfCIType in _LProp:
_LProp.LProp_SequenceOfCIType_swigregister(LProp_SequenceOfCIType)

def LProp_SequenceOfCIType_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _LProp.LProp_SequenceOfCIType_delNode(theNode, theAl)

class LProp_AnalyticCurInf(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _LProp.LProp_AnalyticCurInf_swiginit(self, _LProp.new_LProp_AnalyticCurInf(*args))

    def Perform(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        T: GeomAbs_CurveType
        UFirst: float
        ULast: float
        Result: LProp_CurAndInf

        Returns
        -------
        None

        """
        return _LProp.LProp_AnalyticCurInf_Perform(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _LProp.delete_LProp_AnalyticCurInf

# Register LProp_AnalyticCurInf in _LProp:
_LProp.LProp_AnalyticCurInf_swigregister(LProp_AnalyticCurInf)

class LProp_CurAndInf(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _LProp.LProp_CurAndInf_swiginit(self, _LProp.new_LProp_CurAndInf(*args))

    def AddExtCur(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Param: float
        IsMin: bool

        Returns
        -------
        None

        """
        return _LProp.LProp_CurAndInf_AddExtCur(self, *args)

    def AddInflection(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Param: float

        Returns
        -------
        None

        """
        return _LProp.LProp_CurAndInf_AddInflection(self, *args)

    def Clear(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _LProp.LProp_CurAndInf_Clear(self, *args)

    def IsEmpty(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _LProp.LProp_CurAndInf_IsEmpty(self, *args)

    def NbPoints(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of points. the points are stored to increasing parameter.

        Returns
        -------
        int

        """
        return _LProp.LProp_CurAndInf_NbPoints(self, *args)

    def Parameter(self, *args) -> "Standard_Real":
        r"""
        Returns the parameter of the nth point. raises if n not in the range [1,nbpoints()].

        Parameters
        ----------
        N: int

        Returns
        -------
        float

        """
        return _LProp.LProp_CurAndInf_Parameter(self, *args)

    def Type(self, *args) -> "LProp_CIType":
        r"""
        Returns - mincur if the nth parameter corresponds to a minimum of the radius of curvature. - maxcur if the nth parameter corresponds to a maximum of the radius of curvature. - inflection if the parameter corresponds to a point of inflection. raises if n not in the range [1,nbpoints()].

        Parameters
        ----------
        N: int

        Returns
        -------
        LProp_CIType

        """
        return _LProp.LProp_CurAndInf_Type(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _LProp.delete_LProp_CurAndInf

# Register LProp_CurAndInf in _LProp:
_LProp.LProp_CurAndInf_swigregister(LProp_CurAndInf)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.Contap import *
from OCC.Core.BRepTopAdaptor import *
from OCC.Core.TopTools import *
from OCC.Core.Geom2d import *
from OCC.Core.gp import *
from OCC.Core.HLRAlgo import *


class HLRTopoBRep_ListOfVData:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> HLRTopoBRep_VData: ...
    def Last(self) -> HLRTopoBRep_VData: ...
    def Append(self, theItem: HLRTopoBRep_VData) -> HLRTopoBRep_VData: ...
    def Prepend(self, theItem: HLRTopoBRep_VData) -> HLRTopoBRep_VData: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> HLRTopoBRep_VData: ...
    def SetValue(self, theIndex: int, theValue: HLRTopoBRep_VData) -> None: ...

class HLRTopoBRep_DSFiller:
	@staticmethod
	def Insert(S: TopoDS_Shape, FO: Contap_Contour, DS: HLRTopoBRep_Data, MST: BRepTopAdaptor_MapOfShapeTool, nbIso: int) -> None: ...

class HLRTopoBRep_Data:
	def __init__(self) -> None: ...
	def AddIntL(self, F: TopoDS_Face) -> TopTools_ListOfShape: ...
	def AddIntV(self, V: TopoDS_Vertex) -> None: ...
	def AddIsoL(self, F: TopoDS_Face) -> TopTools_ListOfShape: ...
	def AddOldS(self, NewS: TopoDS_Shape, OldS: TopoDS_Shape) -> None: ...
	def AddOutL(self, F: TopoDS_Face) -> TopTools_ListOfShape: ...
	def AddOutV(self, V: TopoDS_Vertex) -> None: ...
	def AddSplE(self, E: TopoDS_Edge) -> TopTools_ListOfShape: ...
	def Append(self, V: TopoDS_Vertex, P: float) -> None: ...
	def Clean(self) -> None: ...
	def Clear(self) -> None: ...
	def Edge(self) -> TopoDS_Edge: ...
	def EdgeHasSplE(self, E: TopoDS_Edge) -> bool: ...
	def EdgeSplE(self, E: TopoDS_Edge) -> TopTools_ListOfShape: ...
	def FaceHasIntL(self, F: TopoDS_Face) -> bool: ...
	def FaceHasIsoL(self, F: TopoDS_Face) -> bool: ...
	def FaceHasOutL(self, F: TopoDS_Face) -> bool: ...
	def FaceIntL(self, F: TopoDS_Face) -> TopTools_ListOfShape: ...
	def FaceIsoL(self, F: TopoDS_Face) -> TopTools_ListOfShape: ...
	def FaceOutL(self, F: TopoDS_Face) -> TopTools_ListOfShape: ...
	def InitEdge(self) -> None: ...
	def InitVertex(self, E: TopoDS_Edge) -> None: ...
	def InsertBefore(self, V: TopoDS_Vertex, P: float) -> None: ...
	def IsIntLFaceEdge(self, F: TopoDS_Face, E: TopoDS_Edge) -> bool: ...
	def IsIntV(self, V: TopoDS_Vertex) -> bool: ...
	def IsIsoLFaceEdge(self, F: TopoDS_Face, E: TopoDS_Edge) -> bool: ...
	def IsOutLFaceEdge(self, F: TopoDS_Face, E: TopoDS_Edge) -> bool: ...
	def IsOutV(self, V: TopoDS_Vertex) -> bool: ...
	def IsSplEEdgeEdge(self, E1: TopoDS_Edge, E2: TopoDS_Edge) -> bool: ...
	def MoreEdge(self) -> bool: ...
	def MoreVertex(self) -> bool: ...
	def NewSOldS(self, New: TopoDS_Shape) -> TopoDS_Shape: ...
	def NextEdge(self) -> None: ...
	def NextVertex(self) -> None: ...
	def Parameter(self) -> float: ...
	def Vertex(self) -> TopoDS_Vertex: ...

class HLRTopoBRep_FaceData:
	def __init__(self) -> None: ...
	def AddIntL(self) -> TopTools_ListOfShape: ...
	def AddIsoL(self) -> TopTools_ListOfShape: ...
	def AddOutL(self) -> TopTools_ListOfShape: ...
	def FaceIntL(self) -> TopTools_ListOfShape: ...
	def FaceIsoL(self) -> TopTools_ListOfShape: ...
	def FaceOutL(self) -> TopTools_ListOfShape: ...

class HLRTopoBRep_FaceIsoLiner:
	@staticmethod
	def MakeIsoLine(F: TopoDS_Face, Iso: Geom2d_Line, V1: TopoDS_Vertex, V2: TopoDS_Vertex, U1: float, U2: float, Tol: float, DS: HLRTopoBRep_Data) -> None: ...
	@staticmethod
	def MakeVertex(E: TopoDS_Edge, P: gp_Pnt, Par: float, Tol: float, DS: HLRTopoBRep_Data) -> TopoDS_Vertex: ...
	@staticmethod
	def Perform(FI: int, F: TopoDS_Face, DS: HLRTopoBRep_Data, nbIsos: int) -> None: ...

class HLRTopoBRep_OutLiner(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, OriSh: TopoDS_Shape) -> None: ...
	@overload
	def __init__(self, OriS: TopoDS_Shape, OutS: TopoDS_Shape) -> None: ...
	def DataStructure(self) -> HLRTopoBRep_Data: ...
	def Fill(self, P: HLRAlgo_Projector, MST: BRepTopAdaptor_MapOfShapeTool, nbIso: int) -> None: ...
	@overload
	def OriginalShape(self, OriS: TopoDS_Shape) -> None: ...
	@overload
	def OriginalShape(self) -> TopoDS_Shape: ...
	@overload
	def OutLinedShape(self, OutS: TopoDS_Shape) -> None: ...
	@overload
	def OutLinedShape(self) -> TopoDS_Shape: ...

class HLRTopoBRep_VData:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, P: float, V: TopoDS_Shape) -> None: ...
	def Parameter(self) -> float: ...
	def Vertex(self) -> TopoDS_Shape: ...

# harray1 classes
# harray2 classes
# hsequence classes

HLRTopoBRep_DSFiller_Insert = HLRTopoBRep_DSFiller.Insert
HLRTopoBRep_FaceIsoLiner_MakeIsoLine = HLRTopoBRep_FaceIsoLiner.MakeIsoLine
HLRTopoBRep_FaceIsoLiner_MakeVertex = HLRTopoBRep_FaceIsoLiner.MakeVertex
HLRTopoBRep_FaceIsoLiner_Perform = HLRTopoBRep_FaceIsoLiner.Perform



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
ExprIntrp module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_exprintrp.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _ExprIntrp
else:
    import _ExprIntrp

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _ExprIntrp.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _ExprIntrp.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _ExprIntrp.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _ExprIntrp.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _ExprIntrp.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _ExprIntrp.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _ExprIntrp.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _ExprIntrp.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _ExprIntrp.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _ExprIntrp.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _ExprIntrp.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _ExprIntrp.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _ExprIntrp.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _ExprIntrp.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _ExprIntrp.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _ExprIntrp.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _ExprIntrp.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _ExprIntrp:
_ExprIntrp.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _ExprIntrp.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Expr
import OCC.Core.TColStd
import OCC.Core.TCollection

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_ExprIntrp_Generator_Create() -> "opencascade::handle< ExprIntrp_Generator >":
    return _ExprIntrp.Handle_ExprIntrp_Generator_Create()

def Handle_ExprIntrp_Generator_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< ExprIntrp_Generator >":
    return _ExprIntrp.Handle_ExprIntrp_Generator_DownCast(t)

def Handle_ExprIntrp_Generator_IsNull(t: "opencascade::handle< ExprIntrp_Generator > const &") -> "bool":
    return _ExprIntrp.Handle_ExprIntrp_Generator_IsNull(t)

def Handle_ExprIntrp_GenExp_Create() -> "opencascade::handle< ExprIntrp_GenExp >":
    return _ExprIntrp.Handle_ExprIntrp_GenExp_Create()

def Handle_ExprIntrp_GenExp_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< ExprIntrp_GenExp >":
    return _ExprIntrp.Handle_ExprIntrp_GenExp_DownCast(t)

def Handle_ExprIntrp_GenExp_IsNull(t: "opencascade::handle< ExprIntrp_GenExp > const &") -> "bool":
    return _ExprIntrp.Handle_ExprIntrp_GenExp_IsNull(t)

def Handle_ExprIntrp_GenFct_Create() -> "opencascade::handle< ExprIntrp_GenFct >":
    return _ExprIntrp.Handle_ExprIntrp_GenFct_Create()

def Handle_ExprIntrp_GenFct_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< ExprIntrp_GenFct >":
    return _ExprIntrp.Handle_ExprIntrp_GenFct_DownCast(t)

def Handle_ExprIntrp_GenFct_IsNull(t: "opencascade::handle< ExprIntrp_GenFct > const &") -> "bool":
    return _ExprIntrp.Handle_ExprIntrp_GenFct_IsNull(t)

def Handle_ExprIntrp_GenRel_Create() -> "opencascade::handle< ExprIntrp_GenRel >":
    return _ExprIntrp.Handle_ExprIntrp_GenRel_Create()

def Handle_ExprIntrp_GenRel_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< ExprIntrp_GenRel >":
    return _ExprIntrp.Handle_ExprIntrp_GenRel_DownCast(t)

def Handle_ExprIntrp_GenRel_IsNull(t: "opencascade::handle< ExprIntrp_GenRel > const &") -> "bool":
    return _ExprIntrp.Handle_ExprIntrp_GenRel_IsNull(t)
class ExprIntrp_ListIteratorOfStackOfGeneralExpression(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _ExprIntrp.ExprIntrp_ListIteratorOfStackOfGeneralExpression_swiginit(self, _ExprIntrp.new_ExprIntrp_ListIteratorOfStackOfGeneralExpression(*args))

    def More(self) -> "Standard_Boolean":
        return _ExprIntrp.ExprIntrp_ListIteratorOfStackOfGeneralExpression_More(self)

    def Next(self) -> "void":
        return _ExprIntrp.ExprIntrp_ListIteratorOfStackOfGeneralExpression_Next(self)

    def Value(self) -> "opencascade::handle< Expr_GeneralExpression > const &":
        return _ExprIntrp.ExprIntrp_ListIteratorOfStackOfGeneralExpression_Value(self)

    def ChangeValue(self) -> "opencascade::handle< Expr_GeneralExpression > &":
        return _ExprIntrp.ExprIntrp_ListIteratorOfStackOfGeneralExpression_ChangeValue(self)
    __swig_destroy__ = _ExprIntrp.delete_ExprIntrp_ListIteratorOfStackOfGeneralExpression

# Register ExprIntrp_ListIteratorOfStackOfGeneralExpression in _ExprIntrp:
_ExprIntrp.ExprIntrp_ListIteratorOfStackOfGeneralExpression_swigregister(ExprIntrp_ListIteratorOfStackOfGeneralExpression)

class ExprIntrp_ListIteratorOfStackOfGeneralFunction(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _ExprIntrp.ExprIntrp_ListIteratorOfStackOfGeneralFunction_swiginit(self, _ExprIntrp.new_ExprIntrp_ListIteratorOfStackOfGeneralFunction(*args))

    def More(self) -> "Standard_Boolean":
        return _ExprIntrp.ExprIntrp_ListIteratorOfStackOfGeneralFunction_More(self)

    def Next(self) -> "void":
        return _ExprIntrp.ExprIntrp_ListIteratorOfStackOfGeneralFunction_Next(self)

    def Value(self) -> "opencascade::handle< Expr_GeneralFunction > const &":
        return _ExprIntrp.ExprIntrp_ListIteratorOfStackOfGeneralFunction_Value(self)

    def ChangeValue(self) -> "opencascade::handle< Expr_GeneralFunction > &":
        return _ExprIntrp.ExprIntrp_ListIteratorOfStackOfGeneralFunction_ChangeValue(self)
    __swig_destroy__ = _ExprIntrp.delete_ExprIntrp_ListIteratorOfStackOfGeneralFunction

# Register ExprIntrp_ListIteratorOfStackOfGeneralFunction in _ExprIntrp:
_ExprIntrp.ExprIntrp_ListIteratorOfStackOfGeneralFunction_swigregister(ExprIntrp_ListIteratorOfStackOfGeneralFunction)

class ExprIntrp_ListIteratorOfStackOfGeneralRelation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _ExprIntrp.ExprIntrp_ListIteratorOfStackOfGeneralRelation_swiginit(self, _ExprIntrp.new_ExprIntrp_ListIteratorOfStackOfGeneralRelation(*args))

    def More(self) -> "Standard_Boolean":
        return _ExprIntrp.ExprIntrp_ListIteratorOfStackOfGeneralRelation_More(self)

    def Next(self) -> "void":
        return _ExprIntrp.ExprIntrp_ListIteratorOfStackOfGeneralRelation_Next(self)

    def Value(self) -> "opencascade::handle< Expr_GeneralRelation > const &":
        return _ExprIntrp.ExprIntrp_ListIteratorOfStackOfGeneralRelation_Value(self)

    def ChangeValue(self) -> "opencascade::handle< Expr_GeneralRelation > &":
        return _ExprIntrp.ExprIntrp_ListIteratorOfStackOfGeneralRelation_ChangeValue(self)
    __swig_destroy__ = _ExprIntrp.delete_ExprIntrp_ListIteratorOfStackOfGeneralRelation

# Register ExprIntrp_ListIteratorOfStackOfGeneralRelation in _ExprIntrp:
_ExprIntrp.ExprIntrp_ListIteratorOfStackOfGeneralRelation_swigregister(ExprIntrp_ListIteratorOfStackOfGeneralRelation)

class ExprIntrp_SequenceOfNamedExpression(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< Expr_NamedExpression > >::iterator":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< Expr_NamedExpression > >::iterator":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< Expr_NamedExpression > >::const_iterator":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< Expr_NamedExpression > >::const_iterator":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_cend(self)

    def __init__(self, *args):
        _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_swiginit(self, _ExprIntrp.new_ExprIntrp_SequenceOfNamedExpression(*args))

    def Size(self) -> "Standard_Integer":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_Size(self)

    def Length(self) -> "Standard_Integer":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_IsEmpty(self)

    def Reverse(self) -> "void":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_Clear(self, theAllocator)

    def Assign(self, theOther: "ExprIntrp_SequenceOfNamedExpression") -> "NCollection_Sequence< opencascade::handle< Expr_NamedExpression > > &":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_Assign(self, theOther)

    def Set(self, theOther: "ExprIntrp_SequenceOfNamedExpression") -> "NCollection_Sequence< opencascade::handle< Expr_NamedExpression > > &":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "ExprIntrp_SequenceOfNamedExpression") -> "void":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< Expr_NamedExpression > const &":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_First(self)

    def ChangeFirst(self) -> "opencascade::handle< Expr_NamedExpression > &":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< Expr_NamedExpression > const &":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_Last(self)

    def ChangeLast(self) -> "opencascade::handle< Expr_NamedExpression > &":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Expr_NamedExpression > const &":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Expr_NamedExpression > &":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< Expr_NamedExpression > &":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< Expr_NamedExpression > const &") -> "void":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _ExprIntrp.delete_ExprIntrp_SequenceOfNamedExpression

    def __len__(self):
        return self.Size()


# Register ExprIntrp_SequenceOfNamedExpression in _ExprIntrp:
_ExprIntrp.ExprIntrp_SequenceOfNamedExpression_swigregister(ExprIntrp_SequenceOfNamedExpression)

def ExprIntrp_SequenceOfNamedExpression_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _ExprIntrp.ExprIntrp_SequenceOfNamedExpression_delNode(theNode, theAl)

class ExprIntrp_SequenceOfNamedFunction(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< Expr_NamedFunction > >::iterator":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< Expr_NamedFunction > >::iterator":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< Expr_NamedFunction > >::const_iterator":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< Expr_NamedFunction > >::const_iterator":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_cend(self)

    def __init__(self, *args):
        _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_swiginit(self, _ExprIntrp.new_ExprIntrp_SequenceOfNamedFunction(*args))

    def Size(self) -> "Standard_Integer":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_Size(self)

    def Length(self) -> "Standard_Integer":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_IsEmpty(self)

    def Reverse(self) -> "void":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_Clear(self, theAllocator)

    def Assign(self, theOther: "ExprIntrp_SequenceOfNamedFunction") -> "NCollection_Sequence< opencascade::handle< Expr_NamedFunction > > &":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_Assign(self, theOther)

    def Set(self, theOther: "ExprIntrp_SequenceOfNamedFunction") -> "NCollection_Sequence< opencascade::handle< Expr_NamedFunction > > &":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "ExprIntrp_SequenceOfNamedFunction") -> "void":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< Expr_NamedFunction > const &":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_First(self)

    def ChangeFirst(self) -> "opencascade::handle< Expr_NamedFunction > &":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< Expr_NamedFunction > const &":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_Last(self)

    def ChangeLast(self) -> "opencascade::handle< Expr_NamedFunction > &":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Expr_NamedFunction > const &":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Expr_NamedFunction > &":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< Expr_NamedFunction > &":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< Expr_NamedFunction > const &") -> "void":
        return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _ExprIntrp.delete_ExprIntrp_SequenceOfNamedFunction

    def __len__(self):
        return self.Size()


# Register ExprIntrp_SequenceOfNamedFunction in _ExprIntrp:
_ExprIntrp.ExprIntrp_SequenceOfNamedFunction_swigregister(ExprIntrp_SequenceOfNamedFunction)

def ExprIntrp_SequenceOfNamedFunction_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _ExprIntrp.ExprIntrp_SequenceOfNamedFunction_delNode(theNode, theAl)

class ExprIntrp_StackOfGeneralExpression(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_List< opencascade::handle< Expr_GeneralExpression > >::iterator":
        return _ExprIntrp.ExprIntrp_StackOfGeneralExpression_begin(self)

    def end(self) -> "NCollection_List< opencascade::handle< Expr_GeneralExpression > >::iterator":
        return _ExprIntrp.ExprIntrp_StackOfGeneralExpression_end(self)

    def cbegin(self) -> "NCollection_List< opencascade::handle< Expr_GeneralExpression > >::const_iterator":
        return _ExprIntrp.ExprIntrp_StackOfGeneralExpression_cbegin(self)

    def cend(self) -> "NCollection_List< opencascade::handle< Expr_GeneralExpression > >::const_iterator":
        return _ExprIntrp.ExprIntrp_StackOfGeneralExpression_cend(self)

    def __init__(self, *args):
        _ExprIntrp.ExprIntrp_StackOfGeneralExpression_swiginit(self, _ExprIntrp.new_ExprIntrp_StackOfGeneralExpression(*args))

    def Size(self) -> "Standard_Integer":
        return _ExprIntrp.ExprIntrp_StackOfGeneralExpression_Size(self)

    def Assign(self, theOther: "ExprIntrp_StackOfGeneralExpression") -> "NCollection_List< opencascade::handle< Expr_GeneralExpression > > &":
        return _ExprIntrp.ExprIntrp_StackOfGeneralExpression_Assign(self, theOther)

    def Set(self, theOther: "ExprIntrp_StackOfGeneralExpression") -> "NCollection_List< opencascade::handle< Expr_GeneralExpression > > &":
        return _ExprIntrp.ExprIntrp_StackOfGeneralExpression_Set(self, theOther)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _ExprIntrp.ExprIntrp_StackOfGeneralExpression_Clear(self, theAllocator)

    def First(self) -> "opencascade::handle< Expr_GeneralExpression > const &":
        return _ExprIntrp.ExprIntrp_StackOfGeneralExpression_First(self)

    def Last(self) -> "opencascade::handle< Expr_GeneralExpression > const &":
        return _ExprIntrp.ExprIntrp_StackOfGeneralExpression_Last(self)

    def Append(self, *args) -> "void":
        return _ExprIntrp.ExprIntrp_StackOfGeneralExpression_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _ExprIntrp.ExprIntrp_StackOfGeneralExpression_Prepend(self, *args)

    def RemoveFirst(self) -> "void":
        return _ExprIntrp.ExprIntrp_StackOfGeneralExpression_RemoveFirst(self)

    def Remove(self, theIter: "ExprIntrp_ListIteratorOfStackOfGeneralExpression") -> "void":
        return _ExprIntrp.ExprIntrp_StackOfGeneralExpression_Remove(self, theIter)

    def InsertBefore(self, *args) -> "void":
        return _ExprIntrp.ExprIntrp_StackOfGeneralExpression_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _ExprIntrp.ExprIntrp_StackOfGeneralExpression_InsertAfter(self, *args)

    def Reverse(self) -> "void":
        return _ExprIntrp.ExprIntrp_StackOfGeneralExpression_Reverse(self)
    __swig_destroy__ = _ExprIntrp.delete_ExprIntrp_StackOfGeneralExpression

    def __len__(self):
        return self.Size()


# Register ExprIntrp_StackOfGeneralExpression in _ExprIntrp:
_ExprIntrp.ExprIntrp_StackOfGeneralExpression_swigregister(ExprIntrp_StackOfGeneralExpression)

class ExprIntrp_StackOfGeneralFunction(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_List< opencascade::handle< Expr_GeneralFunction > >::iterator":
        return _ExprIntrp.ExprIntrp_StackOfGeneralFunction_begin(self)

    def end(self) -> "NCollection_List< opencascade::handle< Expr_GeneralFunction > >::iterator":
        return _ExprIntrp.ExprIntrp_StackOfGeneralFunction_end(self)

    def cbegin(self) -> "NCollection_List< opencascade::handle< Expr_GeneralFunction > >::const_iterator":
        return _ExprIntrp.ExprIntrp_StackOfGeneralFunction_cbegin(self)

    def cend(self) -> "NCollection_List< opencascade::handle< Expr_GeneralFunction > >::const_iterator":
        return _ExprIntrp.ExprIntrp_StackOfGeneralFunction_cend(self)

    def __init__(self, *args):
        _ExprIntrp.ExprIntrp_StackOfGeneralFunction_swiginit(self, _ExprIntrp.new_ExprIntrp_StackOfGeneralFunction(*args))

    def Size(self) -> "Standard_Integer":
        return _ExprIntrp.ExprIntrp_StackOfGeneralFunction_Size(self)

    def Assign(self, theOther: "ExprIntrp_StackOfGeneralFunction") -> "NCollection_List< opencascade::handle< Expr_GeneralFunction > > &":
        return _ExprIntrp.ExprIntrp_StackOfGeneralFunction_Assign(self, theOther)

    def Set(self, theOther: "ExprIntrp_StackOfGeneralFunction") -> "NCollection_List< opencascade::handle< Expr_GeneralFunction > > &":
        return _ExprIntrp.ExprIntrp_StackOfGeneralFunction_Set(self, theOther)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _ExprIntrp.ExprIntrp_StackOfGeneralFunction_Clear(self, theAllocator)

    def First(self) -> "opencascade::handle< Expr_GeneralFunction > const &":
        return _ExprIntrp.ExprIntrp_StackOfGeneralFunction_First(self)

    def Last(self) -> "opencascade::handle< Expr_GeneralFunction > const &":
        return _ExprIntrp.ExprIntrp_StackOfGeneralFunction_Last(self)

    def Append(self, *args) -> "void":
        return _ExprIntrp.ExprIntrp_StackOfGeneralFunction_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _ExprIntrp.ExprIntrp_StackOfGeneralFunction_Prepend(self, *args)

    def RemoveFirst(self) -> "void":
        return _ExprIntrp.ExprIntrp_StackOfGeneralFunction_RemoveFirst(self)

    def Remove(self, theIter: "ExprIntrp_ListIteratorOfStackOfGeneralFunction") -> "void":
        return _ExprIntrp.ExprIntrp_StackOfGeneralFunction_Remove(self, theIter)

    def InsertBefore(self, *args) -> "void":
        return _ExprIntrp.ExprIntrp_StackOfGeneralFunction_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _ExprIntrp.ExprIntrp_StackOfGeneralFunction_InsertAfter(self, *args)

    def Reverse(self) -> "void":
        return _ExprIntrp.ExprIntrp_StackOfGeneralFunction_Reverse(self)
    __swig_destroy__ = _ExprIntrp.delete_ExprIntrp_StackOfGeneralFunction

    def __len__(self):
        return self.Size()


# Register ExprIntrp_StackOfGeneralFunction in _ExprIntrp:
_ExprIntrp.ExprIntrp_StackOfGeneralFunction_swigregister(ExprIntrp_StackOfGeneralFunction)

class ExprIntrp_StackOfGeneralRelation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_List< opencascade::handle< Expr_GeneralRelation > >::iterator":
        return _ExprIntrp.ExprIntrp_StackOfGeneralRelation_begin(self)

    def end(self) -> "NCollection_List< opencascade::handle< Expr_GeneralRelation > >::iterator":
        return _ExprIntrp.ExprIntrp_StackOfGeneralRelation_end(self)

    def cbegin(self) -> "NCollection_List< opencascade::handle< Expr_GeneralRelation > >::const_iterator":
        return _ExprIntrp.ExprIntrp_StackOfGeneralRelation_cbegin(self)

    def cend(self) -> "NCollection_List< opencascade::handle< Expr_GeneralRelation > >::const_iterator":
        return _ExprIntrp.ExprIntrp_StackOfGeneralRelation_cend(self)

    def __init__(self, *args):
        _ExprIntrp.ExprIntrp_StackOfGeneralRelation_swiginit(self, _ExprIntrp.new_ExprIntrp_StackOfGeneralRelation(*args))

    def Size(self) -> "Standard_Integer":
        return _ExprIntrp.ExprIntrp_StackOfGeneralRelation_Size(self)

    def Assign(self, theOther: "ExprIntrp_StackOfGeneralRelation") -> "NCollection_List< opencascade::handle< Expr_GeneralRelation > > &":
        return _ExprIntrp.ExprIntrp_StackOfGeneralRelation_Assign(self, theOther)

    def Set(self, theOther: "ExprIntrp_StackOfGeneralRelation") -> "NCollection_List< opencascade::handle< Expr_GeneralRelation > > &":
        return _ExprIntrp.ExprIntrp_StackOfGeneralRelation_Set(self, theOther)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _ExprIntrp.ExprIntrp_StackOfGeneralRelation_Clear(self, theAllocator)

    def First(self) -> "opencascade::handle< Expr_GeneralRelation > const &":
        return _ExprIntrp.ExprIntrp_StackOfGeneralRelation_First(self)

    def Last(self) -> "opencascade::handle< Expr_GeneralRelation > const &":
        return _ExprIntrp.ExprIntrp_StackOfGeneralRelation_Last(self)

    def Append(self, *args) -> "void":
        return _ExprIntrp.ExprIntrp_StackOfGeneralRelation_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _ExprIntrp.ExprIntrp_StackOfGeneralRelation_Prepend(self, *args)

    def RemoveFirst(self) -> "void":
        return _ExprIntrp.ExprIntrp_StackOfGeneralRelation_RemoveFirst(self)

    def Remove(self, theIter: "ExprIntrp_ListIteratorOfStackOfGeneralRelation") -> "void":
        return _ExprIntrp.ExprIntrp_StackOfGeneralRelation_Remove(self, theIter)

    def InsertBefore(self, *args) -> "void":
        return _ExprIntrp.ExprIntrp_StackOfGeneralRelation_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _ExprIntrp.ExprIntrp_StackOfGeneralRelation_InsertAfter(self, *args)

    def Reverse(self) -> "void":
        return _ExprIntrp.ExprIntrp_StackOfGeneralRelation_Reverse(self)
    __swig_destroy__ = _ExprIntrp.delete_ExprIntrp_StackOfGeneralRelation

    def __len__(self):
        return self.Size()


# Register ExprIntrp_StackOfGeneralRelation in _ExprIntrp:
_ExprIntrp.ExprIntrp_StackOfGeneralRelation_swigregister(ExprIntrp_StackOfGeneralRelation)

class exprintrp(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    __repr__ = _dumps_object


    def __init__(self):
        _ExprIntrp.exprintrp_swiginit(self, _ExprIntrp.new_exprintrp())
    __swig_destroy__ = _ExprIntrp.delete_exprintrp

# Register exprintrp in _ExprIntrp:
_ExprIntrp.exprintrp_swigregister(exprintrp)

class ExprIntrp_Analysis(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _ExprIntrp.ExprIntrp_Analysis_swiginit(self, _ExprIntrp.new_ExprIntrp_Analysis(*args))

    def GetFunction(self, *args) -> "opencascade::handle< Expr_NamedFunction >":
        r"""
        No available documentation.

        Parameters
        ----------
        name: TCollection_AsciiString

        Returns
        -------
        opencascade::handle<Expr_NamedFunction>

        """
        return _ExprIntrp.ExprIntrp_Analysis_GetFunction(self, *args)

    def GetNamed(self, *args) -> "opencascade::handle< Expr_NamedExpression >":
        r"""
        No available documentation.

        Parameters
        ----------
        name: TCollection_AsciiString

        Returns
        -------
        opencascade::handle<Expr_NamedExpression>

        """
        return _ExprIntrp.ExprIntrp_Analysis_GetNamed(self, *args)

    def IsExpStackEmpty(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _ExprIntrp.ExprIntrp_Analysis_IsExpStackEmpty(self, *args)

    def IsRelStackEmpty(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _ExprIntrp.ExprIntrp_Analysis_IsRelStackEmpty(self, *args)

    def Pop(self, *args) -> "opencascade::handle< Expr_GeneralExpression >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Expr_GeneralExpression>

        """
        return _ExprIntrp.ExprIntrp_Analysis_Pop(self, *args)

    def PopFunction(self, *args) -> "opencascade::handle< Expr_GeneralFunction >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Expr_GeneralFunction>

        """
        return _ExprIntrp.ExprIntrp_Analysis_PopFunction(self, *args)

    def PopName(self, *args) -> "TCollection_AsciiString":
        r"""
        No available documentation.

        Returns
        -------
        TCollection_AsciiString

        """
        return _ExprIntrp.ExprIntrp_Analysis_PopName(self, *args)

    def PopRelation(self, *args) -> "opencascade::handle< Expr_GeneralRelation >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<Expr_GeneralRelation>

        """
        return _ExprIntrp.ExprIntrp_Analysis_PopRelation(self, *args)

    def PopValue(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _ExprIntrp.ExprIntrp_Analysis_PopValue(self, *args)

    def Push(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        exp: Expr_GeneralExpression

        Returns
        -------
        None

        """
        return _ExprIntrp.ExprIntrp_Analysis_Push(self, *args)

    def PushFunction(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        func: Expr_GeneralFunction

        Returns
        -------
        None

        """
        return _ExprIntrp.ExprIntrp_Analysis_PushFunction(self, *args)

    def PushName(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        name: TCollection_AsciiString

        Returns
        -------
        None

        """
        return _ExprIntrp.ExprIntrp_Analysis_PushName(self, *args)

    def PushRelation(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        rel: Expr_GeneralRelation

        Returns
        -------
        None

        """
        return _ExprIntrp.ExprIntrp_Analysis_PushRelation(self, *args)

    def PushValue(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        degree: int

        Returns
        -------
        None

        """
        return _ExprIntrp.ExprIntrp_Analysis_PushValue(self, *args)

    def ResetAll(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _ExprIntrp.ExprIntrp_Analysis_ResetAll(self, *args)

    def SetMaster(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        agen: ExprIntrp_Generator

        Returns
        -------
        None

        """
        return _ExprIntrp.ExprIntrp_Analysis_SetMaster(self, *args)

    def Use(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        func: Expr_NamedFunction

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        named: Expr_NamedExpression

        Returns
        -------
        None

        """
        return _ExprIntrp.ExprIntrp_Analysis_Use(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _ExprIntrp.delete_ExprIntrp_Analysis

# Register ExprIntrp_Analysis in _ExprIntrp:
_ExprIntrp.ExprIntrp_Analysis_swigregister(ExprIntrp_Analysis)

class ExprIntrp_Generator(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetFunction(self, *args) -> "opencascade::handle< Expr_NamedFunction >":
        r"""
        Returns namedfunction with name <name> already interpreted if it exists. returns a null handle if not.

        Parameters
        ----------
        name: TCollection_AsciiString

        Returns
        -------
        opencascade::handle<Expr_NamedFunction>

        """
        return _ExprIntrp.ExprIntrp_Generator_GetFunction(self, *args)

    def GetFunctions(self, *args) -> "ExprIntrp_SequenceOfNamedFunction const &":
        r"""
        No available documentation.

        Returns
        -------
        ExprIntrp_SequenceOfNamedFunction

        """
        return _ExprIntrp.ExprIntrp_Generator_GetFunctions(self, *args)

    def GetNamed(self, *args) -> "opencascade::handle< Expr_NamedExpression >":
        r"""
        No available documentation.

        Returns
        -------
        ExprIntrp_SequenceOfNamedExpression
        Returns namedexpression with name <name> already interpreted if it exists. returns a null handle if not.

        Parameters
        ----------
        name: TCollection_AsciiString

        Returns
        -------
        opencascade::handle<Expr_NamedExpression>

        """
        return _ExprIntrp.ExprIntrp_Generator_GetNamed(self, *args)

    def Use(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        func: Expr_NamedFunction

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        named: Expr_NamedExpression

        Returns
        -------
        None

        """
        return _ExprIntrp.ExprIntrp_Generator_Use(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_ExprIntrp_Generator_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _ExprIntrp.delete_ExprIntrp_Generator

# Register ExprIntrp_Generator in _ExprIntrp:
_ExprIntrp.ExprIntrp_Generator_swigregister(ExprIntrp_Generator)

class ExprIntrp_GenExp(ExprIntrp_Generator):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def Create(*args) -> "opencascade::handle< ExprIntrp_GenExp >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<ExprIntrp_GenExp>

        """
        return _ExprIntrp.ExprIntrp_GenExp_Create(*args)

    def Expression(self, *args) -> "opencascade::handle< Expr_GeneralExpression >":
        r"""
        Returns expression generated. raises an exception if isdone answers false.

        Returns
        -------
        opencascade::handle<Expr_GeneralExpression>

        """
        return _ExprIntrp.ExprIntrp_GenExp_Expression(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns false if any syntax error has occurred during process.

        Returns
        -------
        bool

        """
        return _ExprIntrp.ExprIntrp_GenExp_IsDone(self, *args)

    def Process(self, *args) -> "void":
        r"""
        Processes given string.

        Parameters
        ----------
        str: TCollection_AsciiString

        Returns
        -------
        None

        """
        return _ExprIntrp.ExprIntrp_GenExp_Process(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_ExprIntrp_GenExp_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _ExprIntrp.delete_ExprIntrp_GenExp

# Register ExprIntrp_GenExp in _ExprIntrp:
_ExprIntrp.ExprIntrp_GenExp_swigregister(ExprIntrp_GenExp)

def ExprIntrp_GenExp_Create(*args) -> "opencascade::handle< ExprIntrp_GenExp >":
    r"""
    No available documentation.

    Returns
    -------
    opencascade::handle<ExprIntrp_GenExp>

    """
    return _ExprIntrp.ExprIntrp_GenExp_Create(*args)

class ExprIntrp_GenFct(ExprIntrp_Generator):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def Create(*args) -> "opencascade::handle< ExprIntrp_GenFct >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<ExprIntrp_GenFct>

        """
        return _ExprIntrp.ExprIntrp_GenFct_Create(*args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _ExprIntrp.ExprIntrp_GenFct_IsDone(self, *args)

    def Process(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        str: TCollection_AsciiString

        Returns
        -------
        None

        """
        return _ExprIntrp.ExprIntrp_GenFct_Process(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_ExprIntrp_GenFct_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _ExprIntrp.delete_ExprIntrp_GenFct

# Register ExprIntrp_GenFct in _ExprIntrp:
_ExprIntrp.ExprIntrp_GenFct_swigregister(ExprIntrp_GenFct)

def ExprIntrp_GenFct_Create(*args) -> "opencascade::handle< ExprIntrp_GenFct >":
    r"""
    No available documentation.

    Returns
    -------
    opencascade::handle<ExprIntrp_GenFct>

    """
    return _ExprIntrp.ExprIntrp_GenFct_Create(*args)

class ExprIntrp_GenRel(ExprIntrp_Generator):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def Create(*args) -> "opencascade::handle< ExprIntrp_GenRel >":
        r"""
        No available documentation.

        Returns
        -------
        opencascade::handle<ExprIntrp_GenRel>

        """
        return _ExprIntrp.ExprIntrp_GenRel_Create(*args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns false if any syntax error has occurred during process.

        Returns
        -------
        bool

        """
        return _ExprIntrp.ExprIntrp_GenRel_IsDone(self, *args)

    def Process(self, *args) -> "void":
        r"""
        Processes given string.

        Parameters
        ----------
        str: TCollection_AsciiString

        Returns
        -------
        None

        """
        return _ExprIntrp.ExprIntrp_GenRel_Process(self, *args)

    def Relation(self, *args) -> "opencascade::handle< Expr_GeneralRelation >":
        r"""
        Returns relation generated. raises an exception if isdone answers false.

        Returns
        -------
        opencascade::handle<Expr_GeneralRelation>

        """
        return _ExprIntrp.ExprIntrp_GenRel_Relation(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_ExprIntrp_GenRel_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _ExprIntrp.delete_ExprIntrp_GenRel

# Register ExprIntrp_GenRel in _ExprIntrp:
_ExprIntrp.ExprIntrp_GenRel_swigregister(ExprIntrp_GenRel)

def ExprIntrp_GenRel_Create(*args) -> "opencascade::handle< ExprIntrp_GenRel >":
    r"""
    No available documentation.

    Returns
    -------
    opencascade::handle<ExprIntrp_GenRel>

    """
    return _ExprIntrp.ExprIntrp_GenRel_Create(*args)








#!/usr/bin/env python

##Copyright 2008-2017 Thomas Paviot (tpaviot@gmail.com)
##
##This file is part of pythonOCC.
##
##pythonOCC is free software: you can redistribute it and/or modify
##it under the terms of the GNU Lesser General Public License as published by
##the Free Software Foundation, either version 3 of the License, or
##(at your option) any later version.
##
##pythonOCC is distributed in the hope that it will be useful,
##but WITHOUT ANY WARRANTY; without even the implied warranty of
##MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
##GNU Lesser General Public License for more details.
##
##You should have received a copy of the GNU Lesser General Public License
##along with pythonOCC.  If not, see <http://www.gnu.org/licenses/>.

from __future__ import print_function

import time

try:
    import wx
except ImportError:
    raise ImportError('Please install wxPython.')
from OCC.Display import OCCViewer


class wxBaseViewer(wx.Panel):
    def __init__(self, parent=None):
        wx.Panel.__init__(self, parent)
        self.Bind(wx.EVT_SIZE, self.OnSize)
        self.Bind(wx.EVT_IDLE, self.OnIdle)
        self.Bind(wx.EVT_MOVE, self.OnMove)
        self.Bind(wx.EVT_SET_FOCUS, self.OnFocus)
        self.Bind(wx.EVT_KILL_FOCUS, self.OnLostFocus)
        self.Bind(wx.EVT_MAXIMIZE, self.OnMaximize)
        self.Bind(wx.EVT_LEFT_DOWN, self.OnLeftDown)
        self.Bind(wx.EVT_RIGHT_DOWN, self.OnRightDown)
        self.Bind(wx.EVT_MIDDLE_DOWN, self.OnMiddleDown)
        self.Bind(wx.EVT_LEFT_UP, self.OnLeftUp)
        self.Bind(wx.EVT_RIGHT_UP, self.OnRightUp)
        self.Bind(wx.EVT_MIDDLE_UP, self.OnMiddleUp)
        self.Bind(wx.EVT_MOTION, self.OnMotion)
        self.Bind(wx.EVT_KEY_DOWN, self.OnKeyDown)
        self.Bind(wx.EVT_MOUSEWHEEL, self.OnWheelScroll)

        self._display = None
        self._inited = False

    def GetWinId(self):
        """ Returns the windows Id as an integer.
        issue with GetHandle on Linux for wx versions
        >3 or 4. Window must be displayed before GetHandle is
        called. For that, just wait for a few milliseconds/seconds
        before calling InitDriver
        a solution is given here
        see https://github.com/cztomczak/cefpython/issues/349
        but raises an issue with wxPython 4.x
        finally, it seems that the sleep function does the job
        reported as a pythonocc issue
        https://github.com/tpaviot/pythonocc-core/476
        """
        timeout = 10  # 10 seconds
        win_id = self.GetHandle()
        init_time = time.time()
        delta_t = 0.  # elapsed time, initialized to 0 before the while loop
        # if ever win_id is 0, enter the loop untill it gets a value
        while win_id == 0 and delta_t < timeout:
            time.sleep(0.1)
            wx.SafeYield()
            win_id = self.GetHandle()
            delta_t = time.time() - init_time
        # check that win_id is different from 0
        if win_id == 0:
            raise AssertionError("Can't get win Id")
        # otherwise returns the window Id
        return win_id

    def OnSize(self, event):
        if self._inited:
            self._display.OnResize()

    def OnIdle(self, event):
        pass

    def OnMove(self, event):
        pass

    def OnFocus(self, event):
        pass

    def OnLostFocus(self, event):
        pass

    def OnMaximize(self, event):
        pass

    def OnLeftDown(self, event):
        pass

    def OnRightDown(self, event):
        pass

    def OnMiddleDown(self, event):
        pass

    def OnLeftUp(self, event):
        pass

    def OnRightUp(self, event):
        pass

    def OnMiddleUp(self, event):
        pass

    def OnMotion(self, event):
        pass

    def OnKeyDown(self, event):
        pass


class wxViewer3d(wxBaseViewer):
    def __init__(self, *kargs):
        wxBaseViewer.__init__(self, *kargs)

        self._drawbox = False
        self._zoom_area = False
        self._select_area = False
        self._inited = False
        self._leftisdown = False
        self._middleisdown = False
        self._rightisdown = False
        self._selection = None
        self._scrollwheel = False
        self._key_map = {}
        self.dragStartPos = None

    def InitDriver(self):
        self._display = OCCViewer.Viewer3d(self.GetWinId())
        self._display.Create()
        self._display.SetModeShaded()
        self._inited = True

        # dict mapping keys to functions
        self._SetupKeyMap()

    def _SetupKeyMap(self):
        def set_shade_mode():
            self._display.DisableAntiAliasing()
            self._display.SetModeShaded()
        self._key_map = {ord('W'): self._display.SetModeWireFrame,
                         ord('S'): set_shade_mode,
                         ord('A'): self._display.EnableAntiAliasing,
                         ord('B'): self._display.DisableAntiAliasing,
                         ord('H'): self._display.SetModeHLR,
                         ord('G'): self._display.SetSelectionModeVertex
                        }

    def OnKeyDown(self, evt):
        code = evt.GetKeyCode()
        try:
            self._key_map[code]()
        except KeyError:
            print('unrecognized key %i' % evt.GetKeyCode())

    def OnMaximize(self, event):
        if self._inited:
            self._display.Repaint()

    def OnMove(self, event):
        if self._inited:
            self._display.Repaint()

    def OnIdle(self, event):
        if self._drawbox:
            pass
        elif self._inited:
            self._display.Repaint()

    def Test(self):
        if self._inited:
            self._display.Test()

    def OnFocus(self, event):
        if self._inited:
            self._display.Repaint()

    def OnLostFocus(self, event):
        if self._inited:
            self._display.Repaint()

    def OnPaint(self, event):
        if self._inited:
            self._display.Repaint()

    def ZoomAll(self, evt):
        self._display.FitAll()

    def Repaint(self, evt):
        if self._inited:
            self._display.Repaint()

    def OnLeftDown(self, evt):
        self.SetFocus()
        self.dragStartPos = evt.GetPosition()
        self._display.StartRotation(self.dragStartPos.x, self.dragStartPos.y)

    def OnLeftUp(self, evt):
        pt = evt.GetPosition()
        if self._select_area:
            [Xmin, Ymin, dx, dy] = self._drawbox
            self._display.SelectArea(Xmin, Ymin, Xmin+dx, Ymin+dy)
            self._select_area = False
        else:
            self._display.Select(pt.x, pt.y)

    def OnRightUp(self, evt):
        if self._zoom_area:
            [Xmin, Ymin, dx, dy] = self._drawbox
            self._display.ZoomArea(Xmin, Ymin, Xmin+dx, Ymin+dy)
            self._zoom_area = False

    def OnMiddleUp(self, evt):
        pass

    def OnRightDown(self, evt):
        self.dragStartPos = evt.GetPosition()
        self._display.StartRotation(self.dragStartPos.x, self.dragStartPos.y)

    def OnMiddleDown(self, evt):
        self.dragStartPos = evt.GetPosition()
        self._display.StartRotation(self.dragStartPos.x, self.dragStartPos.y)

    def OnWheelScroll(self, evt):
        # Zooming by wheel
        if evt.GetWheelRotation() > 0:
            zoom_factor = 2.
        else:
            zoom_factor = 0.5
        self._display.Repaint()
        self._display.ZoomFactor(zoom_factor)

    def DrawBox(self, event):
        tolerance = 2
        pt = event.GetPosition()
        dx = pt.x - self.dragStartPos.x
        dy = pt.y - self.dragStartPos.y
        if abs(dx) <= tolerance and abs(dy) <= tolerance:
            return
        dc = wx.ClientDC(self)
        dc.BeginDrawing()
        dc.SetPen(wx.Pen(wx.WHITE, 1, wx.DOT))
        dc.SetBrush(wx.TRANSPARENT_BRUSH)
        dc.SetLogicalFunction(wx.XOR)
        if self._drawbox:
            r = wx.Rect(*self._drawbox)
            dc.DrawRectangleRect(r)
        r = wx.Rect(self.dragStartPos.x, self.dragStartPos.y, dx, dy)
        dc.DrawRectangleRect(r)
        dc.EndDrawing()
        self._drawbox = [self.dragStartPos.x, self.dragStartPos.y, dx, dy]

    def OnMotion(self, evt):
        pt = evt.GetPosition()

        # ROTATE
        if evt.LeftIsDown() and not evt.ShiftDown():
            self._display.Rotation(pt.x, pt.y)
            self._drawbox = False
        # DYNAMIC ZOOM
        elif evt.RightIsDown() and not evt.ShiftDown():
            self._display.Repaint()
            self._display.DynamicZoom(abs(self.dragStartPos.x), abs(self.dragStartPos.y), abs(pt.x), abs(pt.y))
            self.dragStartPos.x = pt.x
            self.dragStartPos.y = pt.y
            self._drawbox = False
        # PAN
        elif evt.MiddleIsDown():
            dx = pt.x - self.dragStartPos.x
            dy = pt.y - self.dragStartPos.y
            self.dragStartPos.x = pt.x
            self.dragStartPos.y = pt.y
            self._display.Pan(dx, -dy)
            self._drawbox = False
        # DRAW BOX
        elif evt.RightIsDown() and evt.ShiftDown():  # ZOOM WINDOW
            self._zoom_area = True
            self.DrawBox(evt)
        elif evt.LeftIsDown() and evt.ShiftDown():  # SELECT AREA
            self._select_area = True
            self.DrawBox(evt)
        else:
            self._drawbox = False
            self._display.MoveTo(pt.x, pt.y)


def TestWxDisplay():
    class AppFrame(wx.Frame):
        def __init__(self, parent):
            wx.Frame.__init__(self, parent, -1, "wxDisplay3d sample",
                              style=wx.DEFAULT_FRAME_STYLE, size=(640, 480))
            self.canva = wxViewer3d(self)

        def runTests(self):
            self.canva._display.Test()

    app = wx.App(False)
    wx.InitAllImageHandlers()
    frame = AppFrame(None)
    frame.Show(True)
    wx.SafeYield()
    frame.canva.InitDriver()
    frame.runTests()
    app.SetTopWindow(frame)
    app.MainLoop()

if __name__ == "__main__":
    TestWxDisplay()
